blob_id
stringlengths
40
40
directory_id
stringlengths
40
40
path
stringlengths
3
264
content_id
stringlengths
40
40
detected_licenses
listlengths
0
85
license_type
stringclasses
2 values
repo_name
stringlengths
5
140
snapshot_id
stringlengths
40
40
revision_id
stringlengths
40
40
branch_name
stringclasses
905 values
visit_date
timestamp[us]date
2015-08-09 11:21:18
2023-09-06 10:45:07
revision_date
timestamp[us]date
1997-09-14 05:04:47
2023-09-17 19:19:19
committer_date
timestamp[us]date
1997-09-14 05:04:47
2023-09-06 06:22:19
github_id
int64
3.89k
681M
star_events_count
int64
0
209k
fork_events_count
int64
0
110k
gha_license_id
stringclasses
22 values
gha_event_created_at
timestamp[us]date
2012-06-07 00:51:45
2023-09-14 21:58:39
gha_created_at
timestamp[us]date
2008-03-27 23:40:48
2023-08-21 23:17:38
gha_language
stringclasses
141 values
src_encoding
stringclasses
34 values
language
stringclasses
1 value
is_vendor
bool
1 class
is_generated
bool
2 classes
length_bytes
int64
3
10.4M
extension
stringclasses
115 values
content
stringlengths
3
10.4M
authors
listlengths
1
1
author_id
stringlengths
0
158
5131eb35ad245e5c54613831d6a07974860405ea
444638431c441ea61f0288cb840f5f48728652a9
/UeWwiseTest/Plugins/Wwise/Source/AkAudio/Classes/MovieSceneAkTrack.h
11f426bde232e1b65118d093a17cd9365bd48026
[]
no_license
Ruslanjke/UeWwise
ebcda44983309e254b127a3afb79cfd606ca2601
b41cddc23be311928c3667463a6cf64c5dc32ab2
refs/heads/main
2023-07-04T01:27:33.025225
2021-08-03T13:59:24
2021-08-03T13:59:24
392,303,381
0
0
null
2021-08-03T13:59:25
2021-08-03T12:04:41
C++
UTF-8
C++
false
false
2,031
h
/******************************************************************************** The content of the files in this repository include portions of the AUDIOKINETIC Wwise Technology released in source code form as part of the SDK package. Commercial License Usage Licensees holding valid commercial licenses to the...
[ "Ruslanjkewow@gmail.com" ]
Ruslanjkewow@gmail.com
68cd19667bb8a870cbbab0103c511a84dbac858c
75ad5fed790b0479bdf24f655e14a2ab45617425
/KalmanFilter/main.cpp
210021e0069aaa81029a26cca3de1bcf75e59cec
[]
no_license
fzyzwrj/VisualTracking
e0a545e38a8e17f469e823c770ee07a603d503c8
d6a578ee8ed59d22e5eb3acb3a4c24e74789c2c0
refs/heads/master
2021-01-11T01:09:58.753832
2017-03-04T08:43:38
2017-03-04T08:43:38
71,048,643
1
0
null
null
null
null
WINDOWS-1252
C++
false
false
1,918
cpp
#define _CRT_SECURE_NO_WARNINGS #include <iostream> #include <fstream> #include <vector> #include <string> #include <cstdio> #include <cstdlib> #include <cassert> #include <opencv2/opencv.hpp> #include "KalmanFilter.h" #include "utils.h" #include "utils_opencv.h" int main() { const std::string posFilename = "C:\\3r...
[ "843063840@qq.com" ]
843063840@qq.com
949b83106c18e76133f901ed1a27768bdc57e2d8
d1cee40adee73afdbce5b3582bbe4761b595c4e1
/back/RtmpLivePushSDK/boost/boost/fusion/view/zip_view/zip_view_iterator.hpp
fa7489f5da96de807e322531b1032e175bfcb4ca
[ "BSL-1.0" ]
permissive
RickyJun/live_plugin
de6fb4fa8ef9f76fffd51e2e51262fb63cea44cb
e4472570eac0d9f388ccac6ee513935488d9577e
refs/heads/master
2023-05-08T01:49:52.951207
2021-05-30T14:09:38
2021-05-30T14:09:38
345,919,594
2
0
null
null
null
null
UTF-8
C++
false
false
1,413
hpp
/*============================================================================= Copyright (c) 2001-2011 Joel de Guzman Copyright (c) 2006 Dan Marsden Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) =====...
[ "wenwenjun@weeget.cn" ]
wenwenjun@weeget.cn
df500bd75e974618eb5b1b13a8d55f8bd4c178ce
1880ae99db197e976c87ba26eb23a20248e8ee51
/cme/include/tencentcloud/cme/v20191029/model/ListMediaRequest.h
709cb077148d0ecf0ac0465a88840b2df067afe9
[ "Apache-2.0" ]
permissive
caogenwang/tencentcloud-sdk-cpp
84869793b5eb9811bb1eb46ed03d4dfa7ce6d94d
6e18ee6622697a1c60a20a509415b0ddb8bdeb75
refs/heads/master
2023-08-23T12:37:30.305972
2021-11-08T01:18:30
2021-11-08T01:18:30
null
0
0
null
null
null
null
UTF-8
C++
false
false
7,647
h
/* * Copyright (c) 2017-2019 THL A29 Limited, a Tencent company. All Rights Reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 ...
[ "tencentcloudapi@tenent.com" ]
tencentcloudapi@tenent.com
75d1c0656b589586596414d03c75b1efebc97f72
2a88b58673d0314ed00e37ab7329ab0bbddd3bdc
/blazetest/src/mathtest/smatdmatmult/SCbSHa.cpp
6558b8b877631cbb45c9c41be29c7225b5d09356
[ "BSD-3-Clause" ]
permissive
shiver/blaze-lib
3083de9600a66a586e73166e105585a954e324ea
824925ed21faf82bb6edc48da89d3c84b8246cbf
refs/heads/master
2020-09-05T23:00:34.583144
2016-08-24T03:55:17
2016-08-24T03:55:17
66,765,250
2
1
NOASSERTION
2020-04-06T05:02:41
2016-08-28T11:43:51
C++
UTF-8
C++
false
false
4,458
cpp
//================================================================================================= /*! // \file src/mathtest/smatdmatmult/SCbSHa.cpp // \brief Source file for the SCbSHa sparse matrix/dense matrix multiplication math test // // Copyright (C) 2013 Klaus Iglberger - All Rights Reserved // // This fil...
[ "klaus.iglberger@gmail.com" ]
klaus.iglberger@gmail.com
eb8558e22bbc924cd84c22dad596e8b1aa5bd40a
8fa1821f2c7a721b72202794e4e78fc48faae7fb
/examples/map_positions.cpp
cab361287dfce80affbc5b9ac4716cd90d90f5bd
[]
no_license
koniiiik/libmultialn
48ce475f5c774226c3e169cc719cc69274f284a9
ada245d4735cd8f4b93caf50c3e0924be6c13ee2
refs/heads/master
2021-01-10T22:11:25.696803
2012-05-29T23:02:46
2012-05-29T23:02:46
null
0
0
null
null
null
null
UTF-8
C++
false
false
3,640
cpp
/* ** This smaple program loads a MAF file according to given parameters, ** maps the positions given on stdin and prints timing statistics. */ #include <string> #include <vector> #include <ctime> #include <iostream> #include <utility> #include <MafReader.h> #include <WholeGenomeAlignment.h> #include <BinSearchAlignm...
[ "michal.petrucha@ksp.sk" ]
michal.petrucha@ksp.sk
8d6dbde8e4a5b6aa786837f597b0dcb39d7ffd3b
4f1cfd10e57707a1c14fed7268410f81d124c0b2
/chrome/browser/ui/views/profiles/profile_menu_view_base.cc
f452966021e006505372332b56cdc45c6f377fb4
[ "BSD-3-Clause" ]
permissive
HeyitsRadin/chromium
30f9bbc02e7e2c67fb16709663caf3bd4c658c46
48797b95315b4441f10b9169767e970c8467033a
refs/heads/master
2023-01-08T07:46:35.102275
2019-10-09T16:47:18
2019-10-09T16:47:18
null
0
0
null
null
null
null
UTF-8
C++
false
false
34,448
cc
// Copyright 2019 The Chromium Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. #include "chrome/browser/ui/views/profiles/profile_menu_view_base.h" #include <algorithm> #include <memory> #include <utility> #include "base/feature_li...
[ "commit-bot@chromium.org" ]
commit-bot@chromium.org
808a7bb66914ac5a07637f1585e7d9512e165883
4b787220c71598e76a9c6f378de10773cc3585e2
/cse331projects/cse331proj1/Project1/Project1/VerifySort.h
158af1ed74eec635f19f8d4af3770eab230c8097
[]
no_license
ShirleyLii/cse331
28e0f2c6b0f8cdd872411446a8ef2856c9618261
d889b482d531d925478014a7ce1d08fa1dcaa357
refs/heads/master
2021-01-20T11:21:44.181574
2015-12-02T21:58:16
2015-12-02T21:58:16
47,290,993
0
0
null
null
null
null
UTF-8
C++
false
false
126
h
#ifndef _VERIFYSORT_H_ #define _VERIFYSORT_H_ #include <vector> using namespace std; //your verify sort here #endif
[ "liyingfe@msu.edu" ]
liyingfe@msu.edu
216d727335942e7b0c8787194847777e7a1e5c48
3cfa229d1d57ce69e0e83bc99c3ca1d005ae38ad
/sphere/source/particle_engine/ParticleInitializer.hpp
1eb4b31705f4b66a0c3944c1a41fe7c7023525e1
[]
no_license
chadaustin/sphere
33fc2fe65acf2eb56e35ade3619643faaced7021
0d74cfb268c16d07ebb7cb2540b7b0697c2a127a
refs/heads/master
2021-01-10T13:28:33.766988
2009-11-08T00:38:57
2009-11-08T00:38:57
36,419,098
2
1
null
null
null
null
UTF-8
C++
false
false
4,201
hpp
#ifndef PARTICLE_INITIALIZER_HPP #define PARTICLE_INITIALIZER_HPP #include "RectangularRange.hpp" #include "EllipticalRange.hpp" #include "Particle.hpp" class ParticleInitializer { public: enum PositionMode { NULL_SHAPE = 0, RECTANGULAR_SHAPE, ELLIPTICAL_SHA...
[ "kyuu@c0eb2ce6-7f40-480a-a1e0-6c4aea08c2c2" ]
kyuu@c0eb2ce6-7f40-480a-a1e0-6c4aea08c2c2
52097e2391a383d95c18f450428a499eb3d68976
0641d87fac176bab11c613e64050330246569e5c
/tags/cldr-22-d04/source/test/intltest/usettest.cpp
021314a9cbe258daa1609fa39e28c69813c7d87d
[ "LicenseRef-scancode-unicode", "ICU" ]
permissive
svn2github/libicu_full
ecf883cedfe024efa5aeda4c8527f227a9dbf100
f1246dcb7fec5a23ebd6d36ff3515ff0395aeb29
refs/heads/master
2021-01-01T17:00:58.555108
2015-01-27T16:59:40
2015-01-27T16:59:40
9,308,333
0
2
null
null
null
null
UTF-8
C++
false
false
133,481
cpp
/* ******************************************************************************** * Copyright (C) 1999-2012 International Business Machines Corporation and * others. All Rights Reserved. ******************************************************************************** * Date Name Description * 10...
[ "emmons@251d0590-4201-4cf1-90de-194747b24ca1" ]
emmons@251d0590-4201-4cf1-90de-194747b24ca1
0a27e9b9d31bd7de6f8e27713770a4a5280b83f7
76299d21dc609cb458ad4b095ba683b23c08f965
/VisionEscapingModify/Server/GaitMove.cpp
70c90f34fe3136368a4ac18a2b217e66447bdba5
[]
no_license
trigrass2/ArisVision
bd942f17c7549bdb63fa95d4e65f344e80764e0d
32ca404491609f8517ec2d38277e62f195a9bf5b
refs/heads/master
2020-06-07T14:11:37.917896
2016-07-20T01:48:57
2016-07-20T01:48:57
null
0
0
null
null
null
null
UTF-8
C++
false
false
2,453
cpp
#include "GaitMove.h" namespace Escaping { double EscapingGaitWrapper::bodyPose[6] = {0, 0, 0, 0, 0, 0}; double EscapingGaitWrapper::feetPosi[18] = {-0.3, -0.85, -0.65, -0.45, -0.85, 0, -0.3, -0.85, 0.65, ...
[ "chaixun@sjtu.edu.cn" ]
chaixun@sjtu.edu.cn
3a7384c94812c3c41768c2ef0d0e776c70a02d14
bddde101270ccb337bfad38196166ef904723d7b
/Sources/EntitiesMP/Common/Particles.cpp
e324239ab24f688546d65a558f8a971a7d616319
[]
no_license
zcaliptium/PESE2
2eeb238beb87d0e3122c3b1c57ea621ea2329669
80d0d867071226084993a60d12be63baa7c42d7f
refs/heads/master
2021-01-18T14:48:54.211634
2015-01-01T21:35:46
2015-01-01T21:35:46
28,695,710
2
0
null
null
null
null
UTF-8
C++
false
false
279,787
cpp
#include "StdH.h" #include "EntitiesMP/BloodSpray.h" #include "EntitiesMP/PlayerWeapons.h" #include "EntitiesMP/WorldSettingsController.h" #include "EntitiesMP/BackgroundViewer.h" #include "EntitiesMP/EnvironmentParticlesHolder.h" static CTextureObject _toRomboidTrail; static CTextureObject _toBombTrail; static CTextu...
[ "zcaliptium@gmail.com" ]
zcaliptium@gmail.com
a39ca8b6e61f8028ef1eda31a1c047a646857482
0e8d57f10639b0bdcab2c89b307029697c909863
/atcoder/abc084/B/main.cpp
b07dfb8108720d86997e526cc13d6288e940624b
[ "Apache-2.0" ]
permissive
xirc/cp-algorithm
07a6faf5228e07037920f5011326c16091a9157d
e83ea891e9f8994fdd6f704819c0c69f5edd699a
refs/heads/main
2021-12-25T16:19:57.617683
2021-12-22T12:06:49
2021-12-22T12:06:49
226,591,291
15
1
Apache-2.0
2021-12-22T12:06:50
2019-12-07T23:53:18
C++
UTF-8
C++
false
false
529
cpp
#include <bits/stdc++.h> using namespace std; bool solve(string const& S, int A, int B) { for (int i = 0; i < A + B + 1; ++i) { if (i == A) { if (S[i] != '-') return false; } else { if (S[i] < '0' || S[i] > '9') return false; } } return true; } int main() {...
[ "xirckey@gmail.com" ]
xirckey@gmail.com
1e3d025b87f176ef8b1709424807e7c3b6a71316
7af069aa20d4ba8ac2dd7147c8dd97f5671d0241
/inc/sol/raii.hpp
22573163ab3f3fd1c29ec195ea74360411a56839
[ "LicenseRef-scancode-unknown-license-reference", "MIT" ]
permissive
epickrram/oppat
780fd18ca2559dea90225823d1e6ad78a6ac75f3
b83602d2c1582487b0cb16af444db3f478f09e73
refs/heads/master
2020-05-23T03:13:38.099717
2019-05-02T17:31:56
2019-05-02T17:31:56
186,611,368
1
0
MIT
2019-05-14T11:49:01
2019-05-14T11:49:01
null
UTF-8
C++
false
false
4,624
hpp
// sol2 // The MIT License (MIT) // Copyright (c) 2013-2018 Rapptz, ThePhD and contributors // Permission is hereby granted, free of charge, to any person obtaining a copy of // this software and associated documentation files (the "Software"), to deal in // the Software without restriction, including without limit...
[ "pf5151@gmail.com" ]
pf5151@gmail.com
19cb9d4065d82f1b4be93a2530f910c5b4310b2e
063a4b8a823e2e3a2804a9aac4d433846904f1fc
/ps/boj/17609_회문.cpp
8efb0172f1abf343c149c46ac2519108ba45c464
[]
no_license
ucinae/algorithm
42d1d8d88336a01528408a480f7872dfa6fad305
68c2c5e6e0a53b3fbd86e0891d81296bee09c15c
refs/heads/master
2022-04-10T19:25:44.194437
2020-03-22T01:48:37
2020-03-22T01:48:37
null
0
0
null
null
null
null
UHC
C++
false
false
2,004
cpp
#include <iostream> using namespace std; // 17609번 회문 // 분류: 회문(Palindrome) // 문제: // 주어진 문자열이 회문인지 유사회문인지 구하기 // 풀이: // 회문인 경우 O(n)에 확인 가능 // 유사회문인 경우 모든 문자 하나씩 빼면서 회문 검사하면 시간 초과 // 그래서 회문 처럼 검사하다가 다른 문자가 나오면 // 왼쪽 문자를 뺄건지 오른쪽 문자를 뺄건지 판단해야 하는데 // 한번은 왼쪽 빼고 한번은 오른쪽 빼서 그 후로 또 빼야하는 경우가 // 생기면 유사회문이 될 수 없고 둘 중 한 ...
[ "onesorry49@gmail.com" ]
onesorry49@gmail.com
a9b5e1a98d75b546cafbb63f09ca090b9922b8c5
4afd8f383a9548ddece248bd7c08246e8ce62fce
/gcf/test/test_cpp/Station.cpp
ba986c7407659ed5a69b8750773f9d6d32ff19f8
[]
no_license
xuantao/small-idea
4f161ae77eadf846e50a3ba8e50f38428cb014d6
a421668bee717bd07880aa6606ebf0d9fd7d867f
refs/heads/master
2020-06-22T06:29:39.837841
2020-05-20T15:43:44
2020-05-20T15:43:44
74,754,319
2
0
null
null
null
null
UTF-8
C++
false
false
3,037
cpp
#include "Station.h" namespace cross_call { SwapBuffer::SwapBuffer(char* buffer, int size) : _header((SwapBuffer::Header*)buffer) , _base((char*)buffer) , _size(size) { } void SwapBuffer::Startup(BufferMode mode) { _mode = mode; _rp = _wp = 4; } in...
[ "xuantao1@kingsoft.com" ]
xuantao1@kingsoft.com
eeba536863bd1d52e1becb465a1bf721eaa0ea8a
6f2b6e9d77fc4dd5e1dae8ba6e5a66eb7c7ae849
/sstd_boost/sstd/boost/statechart/processor_container.hpp
0a154f965d9717a61a89e0c97306d74a66ba138d
[ "BSL-1.0" ]
permissive
KqSMea8/sstd_library
9e4e622e1b01bed5de7322c2682539400d13dd58
0fcb815f50d538517e70a788914da7fbbe786ce1
refs/heads/master
2020-05-03T21:07:01.650034
2019-04-01T00:10:47
2019-04-01T00:10:47
null
0
0
null
null
null
null
UTF-8
C++
false
false
15,341
hpp
#ifndef BOOST_STATECHART_PROCESSOR_CONTAINER_HPP_INCLUDED #define BOOST_STATECHART_PROCESSOR_CONTAINER_HPP_INCLUDED ////////////////////////////////////////////////////////////////////////////// // Copyright 2002-2008 Andreas Huber Doenni // Distributed under the Boost Software License, Version 1.0. (See accompany- //...
[ "zhaixueqiang@hotmail.com" ]
zhaixueqiang@hotmail.com
530a7a4c2fb6f1df8b409dd435e50f8b70e3df77
71bd065fb12ab2d07d4371f1903b45411b91735d
/controller/src/analytics/generator.cc
48f707cffaf1a305c68055740a9464742d3e96f8
[ "Apache-2.0", "LicenseRef-scancode-warranty-disclaimer" ]
permissive
syedaliawaissabir/BGPaaS
dffc3d07eddec91be3d70d8d226b2192511b61ff
71931e462944e39d31ca16167f273ab9fa84145a
refs/heads/master
2020-06-30T23:38:29.650304
2017-07-31T11:13:46
2017-07-31T11:13:46
74,343,705
0
1
null
2016-12-02T14:15:51
2016-11-21T08:46:43
C++
UTF-8
C++
false
false
11,661
cc
/* * Copyright (c) 2013 Juniper Networks, Inc. All rights reserved. */ #include <utility> #include <vector> #include <map> #include <boost/bind.hpp> #include "base/timer.h" #include <boost/date_time/posix_time/posix_time.hpp> #include <boost/assign/list_of.hpp> #include <sandesh/sandesh_types.h> #include <sandesh/s...
[ "awaisalisabir@yahoo.com" ]
awaisalisabir@yahoo.com
5b2ad13370c2ae37c9c6384a975813fce8ffcdfe
63b2135445cf6bc0f238bad2c9e0a659aacae095
/src/lib/solution.h
1d1a5a744bd8fee72950a47510d24c75b1252644
[]
no_license
anujp10/EE_599_HW_2_3
1485ad1ab0d57dd4900999f76abe1e22f56e3cd3
b6a9fbaa5e2d0b6374e3bd2aac21288b6046d8f6
refs/heads/master
2020-12-26T22:40:13.850739
2020-02-02T22:26:35
2020-02-02T22:26:35
237,672,070
0
0
null
null
null
null
UTF-8
C++
false
false
512
h
#ifndef TEMPLATE_SOLUTION_H #define TEMPLATE_SOLUTION_H #include <string> #include <vector> class Solution { public: void RemoveDuplicates(std::vector<int> &input); void SetRemoveDuplicates(std::vector<int> &input); void Reversevector(std::vector<int> &input); void RemoveOddNum(std::vector<int> &input); std...
[ "aspatil@usc.edu" ]
aspatil@usc.edu
cbdd538d186d15843006a97cc5eee2e9af48de30
6a6092b7389c6e43f55406efac7b9caa70550236
/common/JuceReverbAudioClient.cpp
d88c192879885ee57af9513473e4df28eb61170a
[]
no_license
PeakPei/airinstruments
2e2a85201b30660f5538a6c4725a8947b2e30ac7
4cac720b8460eca77b11e15a135798b653550f26
refs/heads/master
2020-03-31T21:12:28.293237
2017-08-23T20:48:49
2017-08-23T20:48:49
null
0
0
null
null
null
null
UTF-8
C++
false
false
1,360
cpp
#include "JuceReverbAudioClient.h" JuceReverbAudioClient::JuceReverbAudioClient() { Reverb::Parameters params; params.roomSize = .8f; params.wetLevel = .5f; params.dryLevel = 0.f; params.damping = 1.f; params.width = 1.f; params.freezeMode = 0.f; reverb.setParameters(params); } JuceRev...
[ "adsomers@gmail.com" ]
adsomers@gmail.com
e8e093dcfefe12676a6c9606f11554df65d80803
f06d9b671187f13eaa27b1ea272d11a9588ac546
/玩转算法面试/3-15-438-Find All Anagrams in a String/3-15-438-Find All Anagrams in a String.cpp
5ea39c511fce0b2e4a2eed8ceb8687a5e6352262
[]
no_license
Rani-Zz/skill-tutorials
49eb3d18d69e2d92b7b34b4c5d8a3db21a4b9749
da50fa072fab2bf49cca6c534472b26bd182ae33
refs/heads/master
2020-05-01T07:57:26.497704
2019-09-11T02:58:57
2019-09-11T02:58:57
177,365,049
0
0
null
null
null
null
UTF-8
C++
false
false
1,405
cpp
#include <iostream> #include<vector> using namespace std; /* run this program using the console pauser or add your own getch, system("pause") or input loop */ /** Given a string s and a non-empty string p, find all the start indices of p's anagrams in s. Strings consists of lowercase English letters only and the leng...
[ "850150293@qq.com" ]
850150293@qq.com
b33756821e982c76281fe7f223a5a99abfd8b780
2220ff0afc630bb7316e0feeac3fa7b94ed6d9d2
/client/node_modules/utp-native/binding.cc
42e40506bc92afda8d78fe26e1b70e70c2dee952
[ "MIT" ]
permissive
premefull/project_numer
94b58d6fa0053fb774ec4c2253ae8a5cb30751ec
21ebc4e2890b0c17892b4f25aed78f8955f6c98b
refs/heads/main
2023-04-21T20:18:48.285368
2021-05-10T21:23:16
2021-05-10T21:23:16
366,134,710
0
0
null
null
null
null
UTF-8
C++
false
false
17,509
cc
#include <node_api.h> #include <napi-macros.h> #include <uv.h> #include <stdlib.h> #include <string.h> #include "./deps/libutp/utp.h" #define UTP_NAPI_TIMEOUT_INTERVAL 500 #define UTP_NAPI_THROW(err) \ { \ napi_throw_error(env, uv_err_name(err), uv_strerror(err)); \ return NULL; \ } #define UTP_NAPI_CALL...
[ "43545924+premefull@users.noreply.github.com" ]
43545924+premefull@users.noreply.github.com
6f2c7e0a0bb6a4ff45a90ed4a5cea9b91d56c32c
514fdafec229bab2b95d4b40d1ec4ddb7f48b1c2
/frameworks/cocos2d-x/cocos/flash/PandoraLib/Notifications.h
ac1c3bc74a0a236ab012334d9480bd10b769be6f
[ "MIT" ]
permissive
xslkim/FlashEngine
409c0b105f4c7bb531954bb00a78c95d2b3d349d
30aedbe92447bcd5bd3c8abd7831776f67f8df46
refs/heads/master
2020-04-24T03:45:23.809432
2019-02-23T11:40:22
2019-02-23T11:40:22
171,680,376
1
0
null
null
null
null
UTF-8
C++
false
false
822
h
#ifndef __NOTIFICATION_H__ #define __NOTIFICATION_H__ #include <string> class INotificationDelegate { public: virtual void onHandleNotification(std::string noteKey, void* object) = 0; }; // Login notification #define NOTE_GAME_LOGIN_SUCCEED "game login succeed" #define NOTE_GAME_LOGIN_TIMEOUT "game l...
[ "xslkim@163.com" ]
xslkim@163.com
ea59920d7eb7bc0787ab98bf9eeab4f259f44411
eaae9f8dbf026a44890ab4a80e0b7b36df160344
/Converter.cpp
006e20191920a358035e843149fbed4fc5c19acd
[]
no_license
tommasolevato/IsMyBabySane
4d47f60d39d3aa64d90e5e616415add14f9efbd1
cff31abc034a3c9a0b8db77a017622b1b4f61583
refs/heads/master
2016-09-06T14:08:09.752784
2014-09-26T14:51:37
2014-09-26T14:51:37
null
0
0
null
null
null
null
UTF-8
C++
false
false
339
cpp
#include "Converter.h" void Converter::convert() { RGBConverter.convert(); DepthConverter.convert(); } wchar_t* Converter::charPtrToWCharPtr(const char* toConvert) { size_t sizeOfToConvert = strlen(toConvert) + 1; wchar_t* toReturn = new wchar_t[sizeOfToConvert]; mbstowcs (toReturn, toConvert, sizeOfToConvert); ...
[ "tommaso.levato@gmail.com" ]
tommaso.levato@gmail.com
2f112b411bab2ea2492ba907cd6810fcbd629016
68eec47af647e7066faf0e796c8a85b5be7dacd1
/test/HumanDetectorTest.cpp
2821ebc422107bb656e60b0f1dd7ca13acc4db01
[ "MIT", "BSD-3-Clause" ]
permissive
urastogi885/humanDetectionModule
644670fad1e0eca849e118bd0d7219dcdf0bdd8f
9b770ae61fdf04ebc4d689a6a24efe38d0c71f63
refs/heads/master
2023-02-04T11:20:24.003281
2023-02-03T21:46:16
2023-02-03T21:46:16
214,243,876
3
4
NOASSERTION
2019-12-11T15:55:55
2019-10-10T17:25:03
C++
UTF-8
C++
false
false
1,447
cpp
/*@ *@file HumanDetectorTest.cpp *@author Aruna Baijal *@brief This is the test class for HumanDetector.cpp *@copyright 2019 Aruna Baijal */ #include <gtest/gtest.h> #include <gmock/gmock.h> #include <HumanDetector.hpp> #include <DescriptorMock.hpp> #include <opencv2/imgcodecs.hpp> #include <opencv2/core/mat.hpp> ...
[ "aruna11baijal@gmail.com" ]
aruna11baijal@gmail.com
046a218b6f0279aaa8cd514d8c2592e5dd494827
1d506a4d22a61f66de9019bf3795d10297ef9e4a
/DB4D/Sources/javascript_db4d.cpp
d3be104f0db0356bf14ba66d80fa659fb8f4fe65
[]
no_license
sanyaade-teachings/core-Components
b439c37bbe0e5d896645848d8db183e40f40b9e7
a93d30e32da6f5fd58c76dfed430093746906ed1
refs/heads/master
2021-01-18T10:56:50.349393
2013-05-16T15:04:40
2013-05-16T15:04:40
null
0
0
null
null
null
null
UTF-8
C++
false
false
172,388
cpp
/* * This file is part of Wakanda software, licensed by 4D under * (i) the GNU General Public License version 3 (GNU GPL v3), or * (ii) the Affero General Public License version 3 (AGPL v3) or * (iii) a commercial license. * This file remains the exclusive property of 4D and/or its licensors * and is protected by na...
[ "stephane.hamel@4d.com" ]
stephane.hamel@4d.com
807d85c734a8eedfe2b7fa9fca270833dbe959cb
f6ef1f50a476c3ed58b4f268feb6fb438996f06a
/有OJ/刷题指南(包含leetcode, POJ, PAT等)/POJ-2/problems/1416ShreddingCompany.cpp
6dd03121b6e9d00a74c9f018df88d4214a9e2b4c
[]
no_license
February13/OJ_Guide
f9d6c72fc2863f5b6f3ad80b0d6c68b51f9a07db
a190942fae29a0dbee306adc81ee245be7fda44a
refs/heads/master
2020-04-25T09:01:48.458939
2018-01-18T08:31:30
2018-01-18T08:31:30
null
0
0
null
null
null
null
UTF-8
C++
false
false
1,556
cpp
#include<iostream> #include<vector> #include<string.h> #include<stdio.h> #include<stack> #include<algorithm> #include<stdlib.h> #include<queue> #include<utility> #include<float.h> #include<math.h> #include<stdlib.h> #include<limits.h> using namespace std; int n,target; int path[6]; int cnt; int best; int best_path[6]; ...
[ "zhaoqijie@pku.edu.cn" ]
zhaoqijie@pku.edu.cn
e0fe4da2d79807529429afa86f1ccfbcd6b1cfb8
b1a7c90e8c3f1722a49ae6f243ffd8cf9127d109
/Client/DinoRun/DinoRun/Objects/BillBoardObject.h
a8de5133686043a4b1185ddf1c0fa2d5eafeafc8
[]
no_license
LEGO0937/Our_Project
805ad70bc724fb66d29fe6ca80519d50475d1c07
eb84718a6792f7993bd18628e21f0d485be05ff1
refs/heads/master
2023-01-18T20:13:54.896165
2020-11-28T06:32:39
2020-11-28T06:32:39
208,686,699
0
0
null
null
null
null
UTF-8
C++
false
false
153
h
#pragma once #include "BaseObject.h" class BillBoardObject : public CGameObject { public: BillBoardObject(int nMeshes = 1); ~BillBoardObject(); };
[ "39212289+LEGO0937@users.noreply.github.com" ]
39212289+LEGO0937@users.noreply.github.com
91f9b68960557aec7b23030ef8ed0515ea1ceb73
0c0b9fb6df7340df22c3fb19a650d9d29ccee98b
/Circuits/Project1/Isrc.h
d1b1bed6cdee08565d6c363de8a92c3912a26a89
[]
no_license
ahmedasad236/Logic_Simulator
ae6221807b2f2f7a94383536b87c9d103e64d46f
1677928c8d3e065df5cdfbb5cc1765767e90383c
refs/heads/master
2023-07-14T11:04:12.153267
2021-08-02T03:03:39
2021-08-02T03:03:39
391,799,239
2
1
null
null
null
null
UTF-8
C++
false
false
30
h
#pragma once class Isrc { };
[ "ahmedasad236@gmail.com" ]
ahmedasad236@gmail.com
62394d8b0eca3fd43185230c409565766caf3296
858e9dcc0cb2d357648825d463bffa858bbc4931
/exercicio_01/include/mod/mexception.hpp
5ee956ad130ee024da3698006a589ec27e05f239
[ "MIT" ]
permissive
matheuscscp/IDJ
2dae85ee84027d23cd698aac2746333721c16a8d
c180717da6a5d1c2a67d022df631adbc9e136e95
refs/heads/master
2020-05-27T00:26:03.417644
2017-02-20T13:40:52
2017-02-20T13:40:52
82,518,994
0
0
null
null
null
null
UTF-8
C++
false
false
1,018
hpp
/// @defgroup MOD_MEXCEP "mexception" /// @{ /// @brief Module to define and implement a new exception class /// @} /// @ingroup MOD_MEXCEP /// @file mexception.hpp /// @brief New exception class and its methods /// @author Matheus Pimenta #ifndef MEXCEPTION_HPP #define MEXCEPTION_HPP #include <string> #include <ios...
[ "matheuscscp@gmail.com" ]
matheuscscp@gmail.com
84511164575f2a866b916c9e7ca12a5c30359061
7d4bea745a1d4593cd686e61f533c2e5287daad3
/Final_Project/Image.cpp
7f8f2c9d5090c66b4b5f1fc816ced65541e0ac31
[]
no_license
chenxeney/Final_Game
4ce3ece4302ad251d2d1ad2d64d3a700e499ee35
76572245fa99abef75fd4ed5a445ba064488a9bd
refs/heads/master
2020-06-08T10:28:01.612037
2019-06-29T02:16:03
2019-06-29T02:16:03
193,206,833
0
0
null
null
null
null
UTF-8
C++
false
false
1,249
cpp
#include <allegro5/allegro.h> #include <memory> #include "IObject.hpp" #include "Image.hpp" #include "Point.hpp" #include "Resources.hpp" using namespace std; namespace Engine { Image::Image(std::string img, float x, float y, float w, float h, float anchorX, float anchorY) : IObject(x, y, w, h, anchorX, anchorY) { ...
[ "chenxeney@gmail.com" ]
chenxeney@gmail.com
1aa30f9343d455feda0178a13d063b46c4bc475d
b6cc2bb32e095a1bbba4cbd6f781d884d2ccb90a
/Creational/4.Abstract_Factory/Factories/LinuxGUIFactory.hpp
6848bed0e0acfebda0f1b582656cc2663bc65014
[]
no_license
Dead-Deus/Design-Patterns
2832881f39ac25d18138fe39e71111fd9c764820
a52e438677ded90d6eca8719c7bc9e08563f222b
refs/heads/master
2023-08-28T00:21:18.290753
2021-10-17T15:16:59
2021-10-17T15:16:59
417,818,777
0
0
null
null
null
null
UTF-8
C++
false
false
195
hpp
#pragma once #include "GUIFactory.hpp" class LinuxButton; class LinuxGUIFactory : public GUIFactory { public: virtual ~LinuxGUIFactory() = default; Button& createButton() override; };
[ "dead_deus@mail.ru" ]
dead_deus@mail.ru
69cfc762cc213ab43bcdbb5a043b317466b923d2
e6258be6d262fc4dc434c91ecef7126276a75d32
/Source/MyProjectX/MyProjectXWheelFront.cpp
42f42dd167e1972114611b025130c14fad441b10
[]
no_license
luoxz-ai/ue4-udp-server
fc0b420076ca7b6724ce6b2d1f99b9013a691ebe
ba0f62929ed02da0a1c091ea3f7255650a605688
refs/heads/master
2022-11-27T20:11:44.936886
2020-07-27T21:24:40
2020-07-27T21:24:40
null
0
0
null
null
null
null
UTF-8
C++
false
false
719
cpp
// Copyright Epic Games, Inc. All Rights Reserved. #include "MyProjectXWheelFront.h" #include "TireConfig.h" #include "UObject/ConstructorHelpers.h" UMyProjectXWheelFront::UMyProjectXWheelFront() { ShapeRadius = 18.f; ShapeWidth = 15.0f; bAffectedByHandbrake = false; SteerAngle = 40.f; // Setup suspension force...
[ "kacmazemin72@gmail.com" ]
kacmazemin72@gmail.com
bf87cc6f13b19dfecb47cd9694951a1dcdc5a433
3be8055c7930a9ae5a3af0f5f7818c595b4d642f
/include/ptrace_proxy.hh
11ff36257ba8f516b1c87f529a183af26774e6b1
[ "MIT" ]
permissive
Hipepper/bdb
8a84ed828ebbbd1a32b229b5e3aac15efef3674b
ed67c24cbcf0f0f9e6cae399f37cce50ada0b85f
refs/heads/master
2021-10-10T17:25:29.929462
2019-01-14T16:38:09
2019-01-14T16:38:09
null
0
0
null
null
null
null
UTF-8
C++
false
false
2,556
hh
#pragma once /** * 将 ptrace 系统调用封装一层 */ #include <sys/ptrace.h> #include <sys/user.h> #include <signal.h> #include <cstdint> namespace BitTech { class PtraceProxy { public: // 唯一一个被 tracee 调用,标志自己被 trace static auto trace_me() -> void { ptrace(PTRACE_TRACEME, 0, nullptr, nullptr); } // ...
[ "peixinchen@foxmail.com" ]
peixinchen@foxmail.com
a64d4bad9220dc5fd1b1ab82b5a27b20f5bf799c
5c62666defa73cd540dfe6556ed4402320005a96
/hw3/part2/page_rank/page_rank.cpp
b9ca6320c79a21a4a151c8c7b2d60e96d894be6b
[]
no_license
yuhua99/pp-2020-fall
e53e3d0e873ac115cca248efdb6daa053569f22c
8a3b6f31fcbabd454102abeab3ddfc336188730c
refs/heads/master
2023-02-16T19:14:40.353693
2021-01-07T12:48:06
2021-01-07T12:48:06
306,267,712
0
0
null
null
null
null
UTF-8
C++
false
false
2,839
cpp
#include "page_rank.h" #include <stdlib.h> #include <cmath> #include <omp.h> #include <utility> #include <vector> #include "../common/CycleTimer.h" #include "../common/graph.h" // pageRank -- // // g: graph to process (see common/graph.h) // solution: array of per-vertex vertex scores (len...
[ "8709142+yuhua99@users.noreply.github.com" ]
8709142+yuhua99@users.noreply.github.com
8a6a68f0d98d8d03bbe1e053dfc4f51f64190cdb
cfeac52f970e8901871bd02d9acb7de66b9fb6b4
/generated/src/aws-cpp-sdk-iot/source/model/DeleteStreamRequest.cpp
4172b629933ce3716ea4a764d705047fb5424961
[ "Apache-2.0", "MIT", "JSON" ]
permissive
aws/aws-sdk-cpp
aff116ddf9ca2b41e45c47dba1c2b7754935c585
9a7606a6c98e13c759032c2e920c7c64a6a35264
refs/heads/main
2023-08-25T11:16:55.982089
2023-08-24T18:14:53
2023-08-24T18:14:53
35,440,404
1,681
1,133
Apache-2.0
2023-09-12T15:59:33
2015-05-11T17:57:32
null
UTF-8
C++
false
false
496
cpp
/** * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved. * SPDX-License-Identifier: Apache-2.0. */ #include <aws/iot/model/DeleteStreamRequest.h> #include <aws/core/utils/json/JsonSerializer.h> #include <utility> using namespace Aws::IoT::Model; using namespace Aws::Utils::Json; using namespace A...
[ "sdavtaker@users.noreply.github.com" ]
sdavtaker@users.noreply.github.com
030f1679b811e2c4b1995f49febceff924872098
52200577bb7a56d108765e4fcb70c9bde27a4ece
/Longest Substring Without Repeating Characters/main.cpp
0ad397f49d67f975f77c081c997fc83e621e1dfd
[]
no_license
zjsxzy/Leetcode
59e7da0319b567b5349a97de401a9990ea7a4df8
d540f0e921cae3b17da7c9f4932d4a3e3419c245
refs/heads/master
2023-08-19T08:50:48.874076
2023-08-06T05:22:37
2023-08-06T05:22:37
13,141,035
2
0
null
null
null
null
UTF-8
C++
false
false
1,362
cpp
#include <map> #include <set> #include <list> #include <cmath> #include <queue> #include <stack> #include <bitset> #include <vector> #include <cstdio> #include <string> #include <cassert> #include <climits> #include <sstream> #include <cstdlib> #include <cstring> #include <iostream> #include <algorithm> using namespace...
[ "zjsxzy@gmail.com" ]
zjsxzy@gmail.com
430a642c39c115b66687d612adf1435ff2019216
da7aa80ea946b805f81828483b0d267508a8f266
/src/bst_map_raw.cxx
e624bc5e67223b43e152d5f5742b832110ae14c2
[]
no_license
nu-ipd/ipd15c
fa3ec5510e0540bf80c5061c9075a441693e6d67
28101f4b9fa5245aee6ee0f8c3c1d069018a7764
refs/heads/master
2023-01-05T17:49:05.797678
2020-11-05T23:26:06
2020-11-05T23:26:06
309,359,090
0
2
null
null
null
null
UTF-8
C++
false
false
3,040
cxx
#include "bst_map_raw.hxx" #include <vector> Bst_map::Bst_map() : size_(0) , root_(nullptr) { } Bst_map::Bst_map(Bst_map const& other) : Bst_map() // << TODO fix this { } Bst_map& Bst_map::operator=(Bst_map const& other) { // TODO complete this return *this; } Bst_map::~Bst_ma...
[ "jesse.tov@gmail.com" ]
jesse.tov@gmail.com
d4b1b4c2fe7bee983a05ff8a3d2c7a91c3a1fa00
3c6deda46fa37a42feebde0fb50dd0d6123b82b1
/0151/src/mess/machine/e05a03.h
36ab639911f9ea1cb10838e6ef9115f4c4b7e31b
[]
no_license
AreaScout/mame-libretro
9fdb724edb58070162c1bd4e8b351a8f2da250ea
dd16543e4f77a2e42f5662a445f03079e2324221
refs/heads/master
2020-12-24T21:01:44.571706
2014-11-26T06:36:49
2014-11-26T06:36:49
null
0
0
null
null
null
null
UTF-8
C++
false
false
2,608
h
/*************************************************************************** E05A03 Gate Array (used in the Epson LX-800) license: MAME, GPL-2.0+ copyright-holders: Dirk Best ***************************************************************************/ #ifndef __E05A03_H__ #define __E05A03_H__ ...
[ "rtype@foo.com" ]
rtype@foo.com
4467f84104d4ae109e1f9b7d4ef9100b572d31c4
5bbd31838d0e3854e5aa08282573d1faf282dfd6
/addons/ofxCurlNoise/src/CurlNoise.cpp
198354a01d492c2978b14f49b0af685a1772ccd0
[ "MIT" ]
permissive
ccabrales/ZoneRush
961b6e692e7e52d85911b3c46e1e7286156df21c
0ded2f31580b9a369b19d59268000cff939e2bbd
refs/heads/master
2021-01-10T13:26:15.780708
2015-12-10T22:44:14
2015-12-10T22:44:14
45,441,010
0
0
null
null
null
null
UTF-8
C++
false
false
8,501
cpp
#include "CurlNoise.h" void CurlNoise::setup(int n){ particlesNumber = n; parameters.setName("Curl noise parameters"); parameters.add(turbulence.set("Turbulence", 0.8, 0.0, 1.0)); advancedParameters.setName("Curl noise advanced parameters"); advancedParameters.add(noisePositionScale.set("Position scale", 0.005...
[ "xiaonan@stanford.edu" ]
xiaonan@stanford.edu
c97e7b108b63adf143cedeabb9a6382a91ca68e2
d9912bf598fc4915d242202bb4db953c48406670
/Namaste/App.h
c233381299d16ace6a06f225d1fbb515648a3d3e
[]
no_license
mwalczyk/libnamaste
210577d0c913f2744e9d22e975c1222b2017a793
70f0892bedc5bd09530dd51d391bcee77f918a17
refs/heads/master
2021-01-21T13:40:44.954510
2017-11-29T22:07:18
2017-11-29T22:07:18
55,818,128
0
0
null
null
null
null
UTF-8
C++
false
false
789
h
#pragma once #include "namaste/Window.h" #include "namaste/Context.h" class App { public: virtual void run(App *app) { app->setup(); do { app->draw(); } while (true); app->exit(); } virtual void setup(); virtual void draw(); virtual void exit(); private: WindowRef mWindow; ContextRef mContext;...
[ "Michael Walczyk" ]
Michael Walczyk
914dc5bf0dddd301479dde70a0ef0fbd68dafc8c
2e7d811953e6776ab84d4bf183f154dfae159862
/geant4.10.01.b01-halfspace_umesh_meshfitvoxel/source/persistency/gdml/src/G4GDMLReadDefine.cc
b3e6a2875a4d3f06f5575e3e24274c7743b8c13c
[]
no_license
Derek-yfqiu/Geant4_AllInOne
8d70f6f43d32dcc20d288867c92530ac795043e6
410602013e5bb4589fcb93bd510e85be6c50b58d
refs/heads/master
2020-03-30T19:57:28.755096
2018-10-04T13:40:12
2018-10-04T13:40:12
151,567,090
2
0
null
null
null
null
UTF-8
C++
false
false
31,576
cc
// // ******************************************************************** // * License and Disclaimer * // * * // * The Geant4 software is copyright of the Copyright Holders of * // * the Geant4 Collaboration...
[ "derek.yfqiu@gmail.com" ]
derek.yfqiu@gmail.com
e7dadc228405a88a889d72e9342790edbef6d1aa
9402c9f35b6d895c3b6f7ddcfc87241e6b9145d8
/Codechef/JuneCookOff/knpsk.cpp
5529ecbfa541cf1ad1e3ad115b45861a992d14d1
[]
no_license
siddharth94/competitive
586d42679558dcd1dcca3457c2ca7be089cbda30
ecda01521a7a9908225771d9374d5c18fa646515
refs/heads/master
2021-07-06T05:27:13.395384
2017-09-29T10:16:20
2017-09-29T10:16:20
105,229,373
0
0
null
null
null
null
UTF-8
C++
false
false
2,166
cpp
#include <bits/stdc++.h> using namespace std; #define F(i,n) for(int i=0;i<n;i++) #define FE(i,n) for(int i=0;i<=n;i++) #define FR(i,n) for(int i=n;i>0;i--) #define FRE(i,n) for(int i=n;i>=0;i--) #define LL long long #define gc getchar_unlocked void get(int &x) { register int c = gc(); x = 0; int neg = 0;...
[ "siddharthgg52@gmail.com" ]
siddharthgg52@gmail.com
dae9102f176f4be61df4f0a1cffaa51f97e9b8e3
9792e9dcb232ab1d49c6b0beacaf13365675a36a
/findNodes.hpp
cd69a86b5a6d7b0c76a7505f9484c79f650d960d
[]
no_license
SUNYOTECH/FingerVein-Recongition
a0c00c0b3ddf0dd903e10ba58f2bd8d398f53e80
d9e2b750457f2d424c6a593a8c26e022148d4ec5
refs/heads/master
2020-03-11T15:25:49.538191
2015-11-17T13:03:50
2015-11-17T13:03:50
null
0
0
null
null
null
null
UTF-8
C++
false
false
377
hpp
// // findNodes.hpp // OpencvTest // // Created by Leque on 2015/11/2. // Copyright © 2015年 LQ. All rights reserved. // #ifndef findNodes_hpp #define findNodes_hpp #include <stdio.h> #include <opencv2/opencv.hpp> #include "SkeletonNodes.h" using namespace cv; int findNodes(Mat dataMat, int block_showPoints, Ske...
[ "caelum@livemail.tw" ]
caelum@livemail.tw
723c9af57408224a17833724403d45daa38e10f8
e4213546785e6737057902c6524e804ffd3e8024
/Open3D_bk/Core/Registration/GlobalOptimization.h
23da1ba4e6d842890b74dfcad2d1b47e9a84f90c
[ "BSD-2-Clause" ]
permissive
brain-cog/Brain_inspired_Batch
358bdc0a1d882d19cfac30232c7c5098114c5fa1
8d33f9690a57bd0828d53c8208d905005629afe7
refs/heads/master
2020-07-23T08:50:28.849312
2019-05-29T01:26:22
2019-05-29T01:26:22
207,504,653
4
2
BSD-2-Clause
2019-09-10T08:26:45
2019-09-10T08:26:44
null
UTF-8
C++
false
false
2,827
h
// ---------------------------------------------------------------------------- // - Open3D: www.open3d.org - // ---------------------------------------------------------------------------- // The MIT License (MIT) // // Copyright (c) 2018 www.open3d.org // // Permissio...
[ "tmczhangtielin@gmail.com" ]
tmczhangtielin@gmail.com
51c877309f2dbfd6f18738c70aaf59f5dc4e1d8d
8acc36b20467cee20e48d9a163d90c65bc1ad98a
/third-party/paxos/src/deptran/executor.h
a69c3cc0bcea1717d729f3c5929351658cb0f885
[ "MIT" ]
permissive
stonysystems/rolis
65fcfdb1c3aea2ce63a525ae5b7a3faa3ac41008
02ae2d91ed31d85ca0ac4464641cf9eddd2612bd
refs/heads/master
2023-04-18T16:15:32.077322
2022-04-17T14:12:31
2022-04-17T14:12:31
466,564,131
19
2
null
null
null
null
UTF-8
C++
false
false
810
h
#pragma once #include "__dep__.h" #include "constants.h" namespace janus { class TxnRegistry; class TxLogServer; class Tx; class SimpleCommand; class TxData; class Executor { public: Recorder* recorder_ = nullptr; TxnRegistry* txn_reg_ = nullptr; mdb::Txn *mdb_txn_ = nullptr; TxLogServer* sched_ = nullptr; ...
[ "shenweihai1@gmail.com" ]
shenweihai1@gmail.com
33dc088fceadd0c9e3c08272dfa2d518dbdec8e7
a68c8d46342e7388a3fda5abdbb56985bd0bb173
/pdedsl/mesh.hpp
8aa5a93308ee9ae274d75e8059290dacbfcc2385
[ "Apache-2.0" ]
permissive
cau-se/sprat-pde-dsl
c50db6d7da9bcd386b23367c4d409a27e7b4e701
15621aaf8b3e78f67f39a7c3c5ae30e02ee7c9ee
refs/heads/master
2020-06-22T12:29:40.935336
2019-07-19T06:38:07
2019-07-19T06:38:07
197,715,281
0
0
null
null
null
null
UTF-8
C++
false
false
753
hpp
/* * Copyright 2014-2015 Arne Johanson * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or a...
[ "arnej@pixelblock.de" ]
arnej@pixelblock.de
32156e6edc7b715efd15a2441fec5e76d47ae53c
9fec729f365812836ca0b6a68031b9e0d6561766
/codeforce/avito_cool_challenge_2018/C.cpp
36f366305caf4b1018167f304c6b015fb1f12cdf
[]
no_license
lee-jeong-geun/ps
d681b47c9c3a7f8f0aa29fae961df5c109f55926
8306c546820be5e089ab52abdc1cb03722adbecb
refs/heads/master
2023-04-23T23:38:48.291444
2021-05-05T16:29:47
2021-05-05T16:29:47
106,931,221
1
0
null
null
null
null
UTF-8
C++
false
false
1,776
cpp
#include <cstdio> #include <iostream> #include <algorithm> #include <cstring> using namespace std; int n, m, k, memo[2005][2][2005], Mod = 998244353; /* 일반적으로 생각하면 [i번째 벽돌][색깔][다른 벽돌 개수]로 메모이제이션 할 수 있다. 하지만 이렇게 하면 [2000][2000][2000]이므로 메모리가 부족해진다. 잘 생각 해보면 현재 상황에서 다음 상황으로 갈 때 필요한 것은 현재 벽돌과 다음 벽돌의 일치 여부이다. 무슨뜻이냐면 현재 벽돌...
[ "–ljk0411jg@naver.com" ]
–ljk0411jg@naver.com
e4b63077949779ecb85bb0392b8ab8cef742ac97
38b057c7dea2e7b9015e3fce67726cb1678a90b1
/libs/z3/src/sat/sat_elim_vars.cpp
1759ec2ad86b166c58395c98a505a0d83f74d695
[ "MIT" ]
permissive
anhvvcs/corana
3ef150667e8124c19238a3f75a875096bbf698c5
dc40868ee4ba1c6148547fb125fddccfb0d446c3
refs/heads/master
2023-08-10T07:04:37.740227
2023-07-24T20:41:30
2023-07-24T20:41:30
181,912,504
34
4
MIT
2023-06-29T03:32:18
2019-04-17T14:49:09
C
UTF-8
C++
false
false
10,257
cpp
/*++ Copyright (c) 2017 Microsoft Corporation Module Name: sat_elim_vars.cpp Abstract: Helper class for eliminating variables Author: Nikolaj Bjorner (nbjorner) 2017-10-14 Revision History: --*/ #include "sat/sat_simplifier.h" #include "sat/sat_elim_vars.h" #include "sat/sat_solver.h" namespace sa...
[ "anhvvcs@gmail.com" ]
anhvvcs@gmail.com
160535b82861d5a4929311e1f5eb133a6113472a
28f83ceed19e8bf66da3c7a83ac3a06431e35fc5
/klib/kSingleton.hpp
752c81743ee1a1b8102a9670646588115f32dc15
[ "MIT" ]
permissive
IGR2014/IgrOS-Kernel
7b1bdd519ef1ecf44b0fe99452055a12c2e22394
ae8497517bb951cc8d25ef752d8749938a9e698a
refs/heads/master
2023-04-29T12:54:45.939879
2023-04-04T11:39:43
2023-04-15T16:54:33
88,917,880
7
2
MIT
2022-12-13T01:16:12
2017-04-20T23:03:14
C++
UTF-8
C++
false
false
1,900
hpp
//////////////////////////////////////////////////////////////// /// /// @brief IgrOS singleton implementation /// /// @file kSingleton.hpp /// @date 21 Mar 2023 /// /// @copyright Copyright (c) 2017 - 2022, /// All rights reserved. /// @author Igor Baklykov /// /// #pragma once // C++ #include <utility> //...
[ "igooor7@gmail.com" ]
igooor7@gmail.com
d532f5d964425932f154d9c21c7e4c7c3a692f75
0ff64ec282aa21f1e204d3d4ad611201e4bd5e2d
/STL/기말고사.cpp
74183e358bf2e28fa1a5654fc9fb471f08d9c9a9
[]
no_license
on1659/STL
77b8f997d6b7229179c5ffddd71696df9b3a9784
2251d5be527ca7872c9d51b18e6def01690618ff
refs/heads/master
2021-06-15T14:17:35.280423
2017-04-03T08:49:13
2017-04-03T08:49:13
87,054,789
2
0
null
null
null
null
UHC
C++
false
false
2,269
cpp
#include "stdafx.h" #include <set> class Animal { protected: int age; public: Animal(int n) : age(n) { }; Animal(Animal& other) { cout << " &" << endl; age = other.age; }; Animal(Animal&& other) { cout << " &&" << endl; age = other.age; other.age = 0; }; Animal() {}; virtual ~Animal() { age ...
[ "on1659@naver.com" ]
on1659@naver.com
8fd77c43c2dcf44586dabaa06cdbb9c3ca8c78b7
904441a3953ee970325bdb4ead916a01fcc2bacd
/src/sys/simulation/simulation_task_keeper.h
0f563fbc2da07a29008a2b3324e7ae8b1d6d61c1
[ "MIT" ]
permissive
itm/shawn
5a75053bc490f338e35ea05310cdbde50401fb50
49cb715d0044a20a01a19bc4d7b62f9f209df83c
refs/heads/master
2020-05-30T02:56:44.820211
2013-05-29T13:34:51
2013-05-29T13:34:51
5,994,638
16
4
null
2014-06-29T05:29:00
2012-09-28T08:33:42
C++
UTF-8
C++
false
false
1,378
h
/************************************************************************ ** This file is part of the network simulator Shawn. ** ** Copyright (C) 2004-2007 by the SwarmNet (www.swarmnet.de) project ** ** Shawn is free software; you can redistribute it and/or modify it ** ** under the terms of t...
[ "github@farberg.de" ]
github@farberg.de
1af43f579a83af200560f333d5ae66db89d758ab
cb51269f05ea1299154c8e8d54612ff4b6eb0382
/libsrc/7z934-src/CPP/Windows/FileLink.cpp
90ffc420976738baaa83886d71fa53b35e9ff9bb
[]
no_license
jinseungim/jmw
d752be358a78aba8e7a78f2357bf48a320c4021d
a41908dd0589d71ebc448ec2272ddb9ad7203d9d
refs/heads/master
2021-01-22T09:04:32.883313
2015-03-13T02:16:28
2015-03-13T02:16:28
32,123,096
0
0
null
null
null
null
UTF-8
C++
false
false
9,485
cpp
// Windows/FileLink.cpp #include "StdAfx.h" #include "../../C/CpuArch.h" #ifdef SUPPORT_DEVICE_FILE #include "../../C/Alloc.h" #endif #include "FileDir.h" #include "FileFind.h" #include "FileIO.h" #include "FileName.h" #ifndef _UNICODE extern bool g_IsNT; #endif namespace NWindows { namespace NFile { using names...
[ "jinseungim@gmail.com" ]
jinseungim@gmail.com
870cd595d21a6a0e044b8848b03eaa7128c4d95f
e82254a9b7c57ef3b082ba76e149075e8d3fe510
/Graphic/terrain/terraineditor.h
0fa999a8378132cfe5d641bfc149517fb2786946
[ "MIT" ]
permissive
sgajaejung/Utility
26a8a768d7f29beb724725e3e9cdfa99db8736ad
9d227861a556914a63bd5accb9cacd86f6abca04
refs/heads/master
2021-01-23T06:34:13.614845
2014-09-19T02:35:48
2014-09-19T02:35:48
null
0
0
null
null
null
null
UHC
C++
false
false
1,776
h
#pragma once namespace graphic { struct sSplatLayer { //int layer; cTexture *texture; sSplatLayer() : texture(NULL) {} //sSplatLayer(int layer0) : layer(layer0) {} //bool operator==(const sSplatLayer &l) { // return layer == l.layer; //} }; class cTerrainEditor : public cTerrain { enum { ...
[ "sgajaejung@gmail.com" ]
sgajaejung@gmail.com
4dbea36f33bcad254e1cfff94ecaf926625c810f
b86d7ba26f9ec19fcd29a03370870c1b41de6d6a
/RigidBodies/PhysicsProjectTests/Test_Matrix.cpp
5f7e5766c88640d57d152376e57d301bfdb448c8
[ "MIT" ]
permissive
mattstruble/PhysicSimulations
68f1583a7568e4462f2fa6220555cd89ce2f4121
29e6b4c07a9faed5997a0023e953bf345f2e7323
refs/heads/master
2021-01-18T21:30:47.030298
2016-03-28T01:06:39
2016-03-28T01:06:39
30,939,833
0
0
null
null
null
null
UTF-8
C++
false
false
5,701
cpp
#include "stdafx.h" #include "CppUnitTest.h" #include "..\PhysicsProject\Matrix.h" #include "..\PhysicsProject\Vector3D.h" using namespace Microsoft::VisualStudio::CppUnitTestFramework; namespace PhysicsProjectTests { TEST_CLASS(MatrixTests) { public: TEST_METHOD(Matrix_TestIdentity) { float* startValu...
[ "mattstruble@outlook.com" ]
mattstruble@outlook.com
b4c4bfe8913f2b548af5b488524e206454475997
d0be9a869d4631c58d09ad538b0908554d204e1c
/utf8/lib/client/FairyCore/src/Core/FairyExpatParser.h
bf9ecade8ea9328dbff533edad7f1b3580131b09
[]
no_license
World3D/pap
19ec5610393e429995f9e9b9eb8628fa597be80b
de797075062ba53037c1f68cd80ee6ab3ed55cbe
refs/heads/master
2021-05-27T08:53:38.964500
2014-07-24T08:10:40
2014-07-24T08:10:40
null
0
0
null
null
null
null
UTF-8
C++
false
false
1,727
h
#ifndef __FAIRYEXPATPARSER_H__ #define __FAIRYEXPATPARSER_H__ #include "FairyXMLParser.h" #define __DAMN_MICROSOFT__ #ifdef __DAMN_MICROSOFT__ #include "FairyUTFString.h" #endif namespace Fairy { struct ConvertBuffer { #ifdef __DAMN_MICROSOFT__ //david-<< UTFString utfString; //david->> #else ...
[ "viticm@126.com" ]
viticm@126.com
735771283ebd08668c9c3abd005c4d719559f773
f4473e90491e419f72f03ae55f62ad0e43b79514
/Page-012-sol/004-impl-sol/991D_1_d1.cpp
594e66249de348f73372bd97aa7d73069af59335
[]
no_license
nishitkshah/My-Codeforces-Submissions
443c2ae476c10bd14a9733cf39e5ad0da591be9a
9671ab0ed70cece4a062ec07b58d8ded5d729c50
refs/heads/master
2020-06-29T14:50:57.749663
2019-08-05T01:55:52
2019-08-05T01:55:52
200,563,917
0
0
null
null
null
null
UTF-8
C++
false
false
1,323
cpp
//11:47 17-08-2018 //11:49 17-08-2018 //12:27 17-08-2018 #include<iostream> #include<string> #include<algorithm> using namespace std; #define RE(a, b, c) for(int a=(b); a<(c); a++) #ifdef DBG #define PA2(a, i, j, n) cerr << #a #j ":"; RE(i, 0, n) cerr << ' ' << a[i][j]; cerr << '\n' #define PIII(a, b, c) cerr << ...
[ "40242169+nishitkshah@users.noreply.github.com" ]
40242169+nishitkshah@users.noreply.github.com
4beb9b439e7bf6c80fde03a46b10befc3265cc32
95382e2a3c25927e78999d26bf90d6b642a5ede0
/百科园-第二章/原题/1/Program.cpp
3882e33f37cb9e7a97a99588e6283df1fcff4ce6
[]
no_license
JulienZeng/bky-data-structure
088dbbb0599287662e2b9d3a54bd6700cfc3cad5
65c7580a815b78a5c86394bbe74f5aa4eb926c7e
refs/heads/master
2023-06-07T17:33:07.797825
2021-06-22T11:45:47
2021-06-22T11:45:47
352,982,979
5
2
null
null
null
null
GB18030
C++
false
false
4,463
cpp
/*------------------------------------------------ 【程序设计】 -------------------------------------------------- 描述 定义一个包含图书信息(书号、书名、价格)的链表, 读入相应的图书数据来完成图书信息表的创建, 然后根据指定的待出库的旧图书的位置,将该图书从图书表中删除, 最后输出该图书出库后的所有图书的信息。 输入 总计n+2行。首先输入n+1行,其中,第一行是图书数目n,后n行是n本图书的信息(书号、书名、价格) ,每本图书信息占一行,书号、书名、价格用空格分隔。之后输入第n+2行, 内容仅为一个整数,代表待删除的旧图书的...
[ "936636589@qq.com" ]
936636589@qq.com
737f4197233527d0461e3552150a1f21d2d771ad
fc3c7d3b0c89906ce37589e7b37870ecc357e83e
/lessons/source-13/adapter.cpp
25320091463d6d4421af9bfd87712e3f6b4c0baf
[]
no_license
gromakovski/clone_repo
283b633716a66b8742955ce09f653bc7f4ff5375
cfdb081411c95a705425645ded61bb186046b96d
refs/heads/master
2020-09-07T16:51:58.960893
2019-11-10T21:24:34
2019-11-10T21:24:34
220,851,558
0
0
null
null
null
null
UTF-8
C++
false
false
2,048
cpp
// Адаптер (Adapter) #include <iostream> // Example 1. class mysql_client_native { public: void mysql_connect() { std::cout << "mysql connect" << std::endl; } void mysql_execute() { std::cout << "mysql execute" << std::endl; } void mysql_close() { std::cout << "mysql clos...
[ "gromakovski" ]
gromakovski
c1c8a3eec357cae3ba68526443a621c892375da4
a8f3019d008bf382fd027302f88908c60c4046e2
/workingForProject/workingForProject/Home/Editor/exe/save_message.cpp
8624b250764686753f56cf56414392ca94dc2fe9
[]
no_license
mehranagh20/C_Programming_Project
8a5da7ee7332091854b1322d3a3685519a5a6eab
fab89d54d1cce8ac613088964eeaa63462773b4d
refs/heads/master
2021-01-13T15:53:50.544415
2016-12-20T06:18:03
2016-12-20T06:18:03
76,799,111
0
0
null
null
null
null
UTF-8
C++
false
false
354
cpp
#include<stdio.h> #include<Windows.h> #include<time.h> int main() { HWND console = GetConsoleWindow(); RECT r; GetWindowRect(console, &r); //stores the console's current dimensions MoveWindow(console, r.left, r.top, 650, 250, TRUE); // 650 width, 250 height printf("\n\n"); printf(" File saved su...
[ "mehranagh200@gmail.com" ]
mehranagh200@gmail.com
6d6ecfada295caaef5ed6b8c2fd0e4d7888ac849
c8b39acfd4a857dc15ed3375e0d93e75fa3f1f64
/Engine/Source/ThirdParty/PhysX/PhysX_3.4/Source/PhysXCharacterKinematic/src/CctSweptVolume.cpp
7e9c0bea4ee88984b3c37c6bef034ed11483b117
[ "MIT", "LicenseRef-scancode-proprietary-license" ]
permissive
windystrife/UnrealEngine_NVIDIAGameWorks
c3c7863083653caf1bc67d3ef104fb4b9f302e2a
b50e6338a7c5b26374d66306ebc7807541ff815e
refs/heads/4.18-GameWorks
2023-03-11T02:50:08.471040
2022-01-13T20:50:29
2022-01-13T20:50:29
124,100,479
262
179
MIT
2022-12-16T05:36:38
2018-03-06T15:44:09
C++
UTF-8
C++
false
false
2,792
cpp
// This code contains NVIDIA Confidential Information and is disclosed to you // under a form of NVIDIA software license agreement provided separately to you. // // Notice // NVIDIA Corporation and its licensors retain all intellectual property and // proprietary rights in and to this software and related documentation...
[ "tungnt.rec@gmail.com" ]
tungnt.rec@gmail.com
f9f720801220b3e6f3ec66e2d2cdf7f6ed631e80
3fc9e78daecdb2f2b4e2389f65ee469acda14bba
/src/masternodeman.cpp
61189448974b5b5c359af5acc98f2dabbbbda270
[ "MIT" ]
permissive
Test-Coin/bederlcore
1edf0c0610b5798799bfa4cec22412d71eff99e5
79c29c1c968593f71468fda267df9d9f44c6fb2d
refs/heads/master
2020-03-27T01:41:01.989484
2018-06-26T14:54:01
2018-06-26T14:54:01
null
0
0
null
null
null
null
UTF-8
C++
false
false
43,414
cpp
// Copyright (c) 2014-2015 The Dash developers // Copyright (c) 2015-2017 The PIVX developers // Distributed under the MIT/X11 software license, see the accompanying // file COPYING or http://www.opensource.org/licenses/mit-license.php. #include "masternodeman.h" #include "activemasternode.h" #include "addrman.h" #inc...
[ "root@localhost.localdomain" ]
root@localhost.localdomain
bead361e78293970eed4819669395a1caec9031b
083092560c57736b41b0b6596bc02d2c55ba94b2
/KangaSchema/RooClonesClassObj.h
2163d409068b2e4b7b212cc20f3ca546c0ad35d9
[]
no_license
marcelkunze/rhoframework
b3d55464cbb9c6127d599356434950787e5668eb
491bfa1c6bcf66760e533505eda77318329ee519
refs/heads/master
2020-06-04T14:44:42.753061
2014-01-24T15:57:25
2014-01-24T15:57:25
33,133,048
0
0
null
null
null
null
UTF-8
C++
false
false
2,098
h
// -*- Mode: c++ -*- // // Class to hold TClonesArray of root // persistent objects. Memory reuse is supported through the // static data member "TClonesArray* _theArray" and the static // member function "setTheArray( TClonesArray* )". If _theArray is // set before objects of this class are created the constructor...
[ "Marcel.Kunze@c13c6a65-7848-45db-51e9-74536fd039a2" ]
Marcel.Kunze@c13c6a65-7848-45db-51e9-74536fd039a2
b09530dbf61c41098f54b1038ea962d2c69c726b
796b89eddc0ca2133eac4abb391f4b15cd03993e
/src/crypto/sha1.cpp
8ca738b78f2046ce2698977c079ea87baee59739
[ "MIT" ]
permissive
Yanick-Salzmann/grower-controller-rpi
a89dd0c0a91029cafd50f162c2d13949737abbdf
30f279e960a3cc8125f112c76ee943b1fa766191
refs/heads/master
2023-02-01T03:50:20.171558
2020-12-17T18:11:43
2020-12-17T18:11:43
310,936,492
0
0
null
null
null
null
UTF-8
C++
false
false
561
cpp
#include "sha1.hpp" #include <openssl/sha.h> #include "utils/basen.hpp" namespace grower::crypto { std::string sha1::hash_base64(const std::string &value) { uint8_t buffer[SHA_DIGEST_LENGTH]{}; SHA1((unsigned char*) value.c_str(), value.size(), buffer); //std::reverse(buffer, buffer + SHA_...
[ "yanick.salzmann@gmail.com" ]
yanick.salzmann@gmail.com
fc0bff5d8f8ab6f3f80028cf1d9512c370c86f06
352a248f54b51d4d4feaf2a9dd02c91252d2c5df
/code/src/test.cpp
f019e59c28a8c4ac4f744b1d27cbcf08160c3f4a
[ "MIT" ]
permissive
Manigandanmps/Helloworld
c5cd908ac270a2ec5558e22b66b88c1ef4065c7b
97e51242b7c436a9a84e7f45df4d96dfd2176aa6
refs/heads/main
2023-02-05T05:49:04.390543
2020-12-24T11:00:35
2020-12-24T11:00:35
324,114,271
0
0
null
null
null
null
UTF-8
C++
false
false
122
cpp
#include "../include/test.hpp" #include <iostream> void HelloWorld() { std::cout << "Hello world!!!" << std::endl; }
[ "manigandanmps@gmail.com" ]
manigandanmps@gmail.com
6936ad66ca925cae7183f845eb541ba269819da9
f5f6d84a908fa97e393e3a53dee945ca3bc9f7b1
/src/span.h
8547c97cfd2ba1f7573a42b7ed7a70c83a64c87a
[ "MIT" ]
permissive
Dollar-coin/Dollar
ff11b24538843006cbe8ab319b89845e1443c946
4b84e5d14408f3985d527aaccac21472b47c91d5
refs/heads/main
2023-02-28T07:05:11.900007
2021-02-08T19:45:28
2021-02-08T19:45:28
335,782,702
1
1
null
null
null
null
UTF-8
C++
false
false
2,999
h
// Copyright (c) 2018 The Bitcoin Core developers // Distributed under the MIT software license, see the accompanying // file COPYING or http://www.opensource.org/licenses/mit-license.php. #ifndef DOLLAR_SPAN_H #define DOLLAR_SPAN_H #include <type_traits> #include <cstddef> #include <algorithm> /** A Span is an obje...
[ "thebest866@protonmail.com" ]
thebest866@protonmail.com
5a910196a9c995a215d3600ae45ecf6658727a56
a7764174fb0351ea666faa9f3b5dfe304390a011
/drv/StepData/StepData_EDescr.ixx
cff9c5849f38158e52d0468ab7d5fd6bd92024d3
[]
no_license
uel-dataexchange/Opencascade_uel
f7123943e9d8124f4fa67579e3cd3f85cfe52d91
06ec93d238d3e3ea2881ff44ba8c21cf870435cd
refs/heads/master
2022-11-16T07:40:30.837854
2020-07-08T01:56:37
2020-07-08T01:56:37
276,290,778
0
0
null
null
null
null
UTF-8
C++
false
false
711
ixx
// This file is generated by WOK (CPPExt). // Please do not edit this file; modify original file instead. // The copyright and license terms as defined for the original file apply to // this header file considered to be the "object code" form of the original source. #include <StepData_EDescr.jxx> #ifndef _Standard_T...
[ "shoka.sho2@excel.co.jp" ]
shoka.sho2@excel.co.jp
092f2143defebee438770fb12b8500567310842f
7cb9f663565aad0ae77f5627e562859af9a0231b
/interface/config/node/tests/base.cpp
e994aab33aa491559c8a51b3722c32e1446a9f54
[ "BSD-3-Clause" ]
permissive
ArcticNature/core
33e9708869efb792005fca546b1e1868e120a283
bb63529a6deadc83e5adc3b772738ab6ca6ba18a
refs/heads/master
2021-01-17T07:09:57.807091
2017-07-08T16:28:20
2017-07-08T16:28:20
48,641,672
0
0
null
null
null
null
UTF-8
C++
false
false
10,262
cpp
// Copyright 2016 Stefano Pogliani <stefano@spogliani.net> #include <gtest/gtest.h> #include <memory> #include <string> #include <vector> #include "core/context/context.h" #include "core/context/static.h" #include "core/event/source/manual.h" #include "core/interface/config/node.h" #include "core/model/cli-parser.h"...
[ "stefano@spogliani.net" ]
stefano@spogliani.net
63c52a004d2e381e90758ad47616bdf7a1d2283e
8dc84558f0058d90dfc4955e905dab1b22d12c08
/services/ui/ws2/event_test_utils.h
ec3ba02065c15642aa9a906e7228778c34732af5
[ "LicenseRef-scancode-unknown-license-reference", "BSD-3-Clause" ]
permissive
meniossin/src
42a95cc6c4a9c71d43d62bc4311224ca1fd61e03
44f73f7e76119e5ab415d4593ac66485e65d700a
refs/heads/master
2022-12-16T20:17:03.747113
2020-09-03T10:43:12
2020-09-03T10:43:12
263,710,168
1
0
BSD-3-Clause
2020-05-13T18:20:09
2020-05-13T18:20:08
null
UTF-8
C++
false
false
731
h
// Copyright 2018 The Chromium Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. #ifndef SERVICES_UI_WS2_EVENT_TEST_UTILS_H_ #define SERVICES_UI_WS2_EVENT_TEST_UTILS_H_ #include <string> namespace ui { class Event; namespace ws2 { ...
[ "arnaud@geometry.ee" ]
arnaud@geometry.ee
74cf473a8b896a6ae32bdedce76df971db219fe4
ccc43d07758f1dda046c5d327df178f2e4406dbd
/nowcoder/huawei/密码截取.cpp
5f7ec223ddc8a4f7935b8450ee4f7563927121b3
[]
no_license
dengbohhxx/vscode
db36eb0b4b8edb6cc64c91e67f18ac39bf07516c
13abdc92788985ee0299b0d0aa436188780de7f8
refs/heads/master
2023-03-31T16:04:41.839580
2021-04-04T08:36:29
2021-04-04T08:36:29
298,458,891
0
0
null
null
null
null
UTF-8
C++
false
false
739
cpp
#include<iostream> #include<string> #include<vector> using namespace std; int getLongestPalindrome(string A, int n) { vector<vector<bool> > dp(n,vector<bool>(n,false)); int m=0; for(int d=0;d<n;d++) { for(int i=0;i<n-d;i++) { int j=i+d; if(A[i]==A[j]) ...
[ "dengbohhxx@sina.com" ]
dengbohhxx@sina.com
54543796c933894d0f141802b748169392604801
8d8507655970723484d8d3fd4d04b3ef4879855c
/code/AzCore/std/hash_table.h
cfea957105b201cd962480879ecd73c46a8eae5e
[]
no_license
leafnsand/xEngine
305b69069d93cfc1bf1e3f426cb31c6d2f15da1e
05b83ba249e2c9517253c50b13264b4514b3b34e
refs/heads/master
2020-05-21T20:11:05.684108
2019-08-06T03:35:34
2019-08-06T03:35:34
60,331,266
5
4
null
null
null
null
UTF-8
C++
false
false
45,118
h
/* * All or portions of this file Copyright (c) Amazon.com, Inc. or its affiliates or * its licensors. * * For complete copyright and license terms please see the LICENSE at the root of this * distribution (the "License"). All use of this software is governed by the License, * or, if provided, by the license below or t...
[ "xavierjiang@hotmail.com" ]
xavierjiang@hotmail.com
9a506eec30e06a191f492c8e4d0056cb2cf32e04
f999711a794bd8f28b3365fa9333403df179fd90
/primer c++ plus/c++程序/第四章/指针/new和delete.cpp
14c5f31dc7f3b3f0c8696919ec51d6582585dc63
[]
no_license
Hanray-Zhong/Computer-Science
2423222addff275e5822a1390b43c44c1b24a252
dfea9d3ee465c36a405e50f53589bdacbd6d2ae2
refs/heads/master
2021-07-04T21:35:43.730153
2020-08-07T09:56:58
2020-08-07T09:56:58
145,799,254
0
1
null
null
null
null
GB18030
C++
false
false
578
cpp
#include <iostream> #include <cstring> using namespace std; char* getname(void); //自定义函数,返还一个指针的地址 int main() { char* name; name=getname(); cout<<name<<" at "<<(int*)name<<endl; delete [] name; name=getname(); cout<<name<<" at "<<(int*)name<<endl; delete [] name...
[ "646374316@qq.com" ]
646374316@qq.com
3ce008da75da1f282b218b7b9064948a728295ab
d0c44dd3da2ef8c0ff835982a437946cbf4d2940
/cmake-build-debug/programs_tiling/function14431/function14431_schedule_20/function14431_schedule_20.cpp
62477d447179e6e598ce47536c15fcecbd6f661c
[]
no_license
IsraMekki/tiramisu_code_generator
8b3f1d63cff62ba9f5242c019058d5a3119184a3
5a259d8e244af452e5301126683fa4320c2047a3
refs/heads/master
2020-04-29T17:27:57.987172
2019-04-23T16:50:32
2019-04-23T16:50:32
176,297,755
1
2
null
null
null
null
UTF-8
C++
false
false
1,993
cpp
#include <tiramisu/tiramisu.h> using namespace tiramisu; int main(int argc, char **argv){ tiramisu::init("function14431_schedule_20"); constant c0("c0", 4096), c1("c1", 64), c2("c2", 128); var i0("i0", 0, c0), i1("i1", 0, c1), i2("i2", 0, c2), i01("i01"), i02("i02"), i03("i03"), i04("i04"), i05("i05"), ...
[ "ei_mekki@esi.dz" ]
ei_mekki@esi.dz
607d99702cc41f737da3d2df250639415c83eb05
0368c1ed37cf0e7da5dbee531c770de1b0902d78
/NFLTour-master/showtour.h
930247b8dd333b7ba83efcbfc76108068cb62d8a
[]
no_license
shahin-fotowat/NFL-Tour
13c44eefa9252a2c9998e84fcf1eddebb6e8426b
ef154a1ff3f83b8a135e4ca6fc460e1440c99414
refs/heads/master
2020-11-25T03:11:12.434797
2019-12-17T09:46:46
2019-12-17T09:46:46
228,474,073
0
0
null
null
null
null
UTF-8
C++
false
false
1,277
h
#ifndef SHOWTOUR_H #define SHOWTOUR_H #include <QWidget> #include <vector> #include <QDebug> #include <QLineEdit> #include <QLabel> #include <QSqlQuery> #include <map> namespace Ui { class ShowTour; } /** * @brief The ShowTour class allows the user to start a tour and purchase souvenirs */ class ShowTour : public...
[ "sfototwa@uci.edu" ]
sfototwa@uci.edu
0b53d9e905af9bc23a64358697cdea3050a361c6
f7df6576f641633ffa1290969e7b6da48ee3c26d
/src/OrbitBase/FutureTest.cpp
ecf4d40f71e1e8a222f4c1f24f8b397eb34bdbd2
[ "BSD-2-Clause", "LicenseRef-scancode-free-unknown" ]
permissive
beckerhe/orbitprofiler
96fa8466dac647618e42ff45319d70aceb4505cc
56541e1e53726f9f824e8216fdcbd4e7b1178965
refs/heads/main
2023-06-06T01:08:10.490090
2021-12-10T13:31:51
2021-12-10T13:31:51
235,291,165
2
0
BSD-2-Clause
2021-12-10T13:31:51
2020-01-21T08:32:27
C++
UTF-8
C++
false
false
6,646
cpp
// Copyright (c) 2021 The Orbit Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. #include <gtest/gtest.h> #include "OrbitBase/Future.h" #include "OrbitBase/ImmediateExecutor.h" #include "OrbitBase/Promise.h" namespace orbit_base { ...
[ "43133967+beckerhe@users.noreply.github.com" ]
43133967+beckerhe@users.noreply.github.com
2b00b2658d59a81f52c41f8a7ed22bd36089aff6
b662bcb1fc6064d84fa3ef6dc5e0494e3c448148
/assignments/hw1/src/Ray.h
f29bafa0e41420170b65620610ba65cd659c437b
[]
no_license
bozbalci/giraffe
27bf100a973658d40b74f75b694bd9d72108b033
7603420476a5061094e0d4fee1b07f4c040b73ac
refs/heads/master
2020-08-12T22:44:11.446161
2020-01-20T14:18:48
2020-01-20T14:18:48
214,857,189
1
1
null
null
null
null
UTF-8
C++
false
false
576
h
#ifndef _RAY_H_ #define _RAY_H_ #include "defs.h" // Class for Ray object. class Ray { public: vec3f origin; // Origin of the ray vec3f direction; // Direction of the ray Ray(); // Constuctor Ray(const vec3f &origin, const vec3f &direction); // Constuct...
[ "berkozbalci@gmail.com" ]
berkozbalci@gmail.com
e4fa78629457a2aa703d4dd76417b84527f53bf6
28969b365459fdb742082c29b96bb0fd3908e168
/L2Auth/src/logger/LogType.cpp
418470cdd27e2a99eee45b15ba16a999a9e779c9
[]
no_license
ChaosPaladin/L2Auth
3168f05b60a61dbe4c4e1c324cc06e9424b69dcb
8f46568bb647c9b6b775d994790289c3446fc46f
refs/heads/devel
2021-01-22T04:10:11.917017
2017-05-25T19:22:49
2017-05-25T19:22:49
92,436,627
3
1
null
2017-05-25T19:22:50
2017-05-25T19:20:49
Assembly
UTF-8
C++
false
false
28
cpp
#include "logger/LogType.h"
[ "master.toma87@gmail.com" ]
master.toma87@gmail.com
ac9372a3d16f3795b4415b35c2318280622b5d4d
428989cb9837b6fedeb95e4fcc0a89f705542b24
/erle/ros2_ws/install/include/rcl_interfaces/srv/list_parameters__traits.hpp
4f7bba5fb847e37658fc187a822d4b9c58eb8a90
[]
no_license
swift-nav/ros_rover
70406572cfcf413ce13cf6e6b47a43d5298d64fc
308f10114b35c70b933ee2a47be342e6c2f2887a
refs/heads/master
2020-04-14T22:51:38.911378
2016-07-08T21:44:22
2016-07-08T21:44:22
60,873,336
1
2
null
null
null
null
UTF-8
C++
false
false
107
hpp
/home/erle/ros2_ws/build/rcl_interfaces/rosidl_generator_cpp/rcl_interfaces/srv/list_parameters__traits.hpp
[ "igdoty@swiftnav.com" ]
igdoty@swiftnav.com
265a9cb8e1adc57ea4a3710b4004ca48cdd29411
b96a9f38779feb7cffafdcffbf56ea1d94323f1d
/ECS/Systems/thirdpersoncamerasystem.h
6bdaa33e6b8b2ee4b0dc829a21f0424547601b66
[]
no_license
Frolt/FroltEngine
e366e4954f1694f6191ba1ae46031d18d19b5bd4
16b17be523fb48a0c9cd71db54ac630284207f1d
refs/heads/master
2020-03-28T22:03:31.065513
2018-12-08T20:00:25
2018-12-08T20:00:25
149,202,215
0
0
null
null
null
null
UTF-8
C++
false
false
789
h
#ifndef THIRDPERSONCAMERASYSTEM_H #define THIRDPERSONCAMERASYSTEM_H #include "ECS/system.h" /** @brief The ThirdPersonCameraSystem class implements a camera that always looks at the relevant entity location (usually the player) The cameras rotation is controlled by the mouse movement. The camera considers ...
[ "alexanderkamperhaug@hotmail.com" ]
alexanderkamperhaug@hotmail.com
4d0adc7f5b43cdba9402ca9cf70d2aee4653694a
a365806398da3078d721e5d960999d5c75860a3b
/tcpnative/tcp_request_parser.hpp
4c73e75c91aaef247ca7f651b1b194706bae8a84
[]
no_license
Dmitry666/HTTPCommandService
352202e8973faba9ad8ceb8ff8de4495ed583a03
363dff91288ea0029aa765cb6f151b85418d5608
refs/heads/master
2021-07-13T18:58:15.894313
2021-07-02T12:01:07
2021-07-02T12:01:07
34,256,316
1
1
null
2021-07-02T12:01:08
2015-04-20T11:25:33
C++
UTF-8
C++
false
false
997
hpp
#ifndef TCP_REQUEST_PARSER_HPP #define TCP_REQUEST_PARSER_HPP #include <tuple> #include <string> namespace openrc { namespace tcpnative { struct request; /// Parser for incoming requests. class request_parser { public: /// Construct ready to parse the request method. request_parser(); /// Reset to init...
[ "gamexgroup@gmail.com" ]
gamexgroup@gmail.com
eb2f1c86d2ac41c58e5348ff40546620661d983f
3126e1fa7b5e1dd5b324703b5b1a2fc8596c7ca9
/nn/NeuralCoordinator.hpp
d8b0c25176546998c9153eaf71a821a4df7047ba
[]
no_license
TatianaJin/dl_lsh
2229b7ca6b849cb00289b715b214d8b5ba018abc
498ebf97a311370949f451c3b015977800b5063f
refs/heads/master
2021-07-14T18:12:13.316175
2017-10-13T06:34:01
2017-10-13T06:34:29
105,144,595
0
1
null
null
null
null
UTF-8
C++
false
false
5,486
hpp
#ifndef NEURALCOORDINATOR_HPP #define NEURALCOORDINATOR_HPP #include <Eigen/Dense> #include <cassert> #include <cstdlib> #include <ctime> #include <iostream> #include <memory> #include <numeric> #include <string> #include <thread> #include <vector> #include "exp/colors.hpp" #include "nn/HiddenLayer.hpp" #include "nn/...
[ "tatiana.jin.xy@gmail.com" ]
tatiana.jin.xy@gmail.com
b295a13578cb29efcaf6ad095b6535c624b54742
ebc7589f4f894059d84253e3f394b243bea05049
/MPI_BayesC/mainMPI_2.cpp
877271ebc056e17780551f5c9921d37de3ed1077
[]
no_license
reworkhow/MPI
2eb993c8e18309eb7b35c4dfc726f0804823082c
2fce76d891972c1b7d4bc4c34e9245b8568533bf
refs/heads/master
2020-06-23T23:05:57.430870
2016-12-08T07:29:16
2016-12-08T07:29:16
74,638,345
0
1
null
null
null
null
UTF-8
C++
false
false
9,689
cpp
// main.cpp // BayesCPi (MPI Parallel Computing) #include <iostream> #include <Eigen> #include <string> #include <iostream> #include <fstream> #include <matvec/statdist.h> #include <matvec/session.h> #include <mpi.h> #include <ctime> typedef Eigen::Map<Eigen::VectorXf> MVectorXf; using namespace std; float c...
[ "reworkhow@gmail.com" ]
reworkhow@gmail.com
c1f821c693636deaab20a0dbe5513c1b2ebd412e
e807b0c3b69e9ce05e32b8f5cf6c7c805e0d2a06
/cob_people_detection/ros/src/openni_tracker.cpp
51ede7dbb4df11b373c87886a977037ec3f24699
[]
no_license
leis/cob_people_perception
5dce8ff5efaa4a1c7508d3a534064bfe6bb81acc
211f44094e74fdbe1c0a6ad1317fd30e543cfd0c
refs/heads/master
2021-01-16T19:53:45.500125
2012-12-19T15:45:20
2012-12-19T15:45:20
null
0
0
null
null
null
null
UTF-8
C++
false
false
7,120
cpp
// openni_tracker.cpp #include <ros/ros.h> #include <ros/package.h> #include <tf/transform_broadcaster.h> #include <kdl/frames.hpp> #include "cob_people_detection/SceneDrawer.h" #include <XnOpenNI.h> #include <XnCodecIDs.h> #include <XnCppWrapper.h> using std::string; xn::Context g_Context; xn::DepthGenerato...
[ "Richard.Bormann@ipa.fraunhofer.de" ]
Richard.Bormann@ipa.fraunhofer.de
85ecc883ae1808d7a26e1a7b6b747bc717aa6ee2
aca909394b0fed2ad91a8d4f6c933d133d4bab43
/Creature/CreaturePredicates.h
deac3ffd416b8b6d8a584bf662ad17c006e62230
[]
no_license
Paltr/SeaBoom
31f54b4df8f32f56a33c69f73e0dc9d009f567dc
805437d8d2dade45aa2a08f00f0218de4ee82252
refs/heads/master
2021-01-10T16:03:27.127284
2016-01-28T17:54:36
2016-01-28T17:54:36
50,601,493
0
0
null
null
null
null
UTF-8
C++
false
false
3,989
h
#ifndef CREATUREPREDICATES_17_17_45_H__ #define CREATUREPREDICATES_17_17_45_H__ /********************************************************************************************************* created: 2011/10/15 file base: CreaturePredicates file ext: h author: Paltr purpose: history:...
[ "berzerger@yandex.ru" ]
berzerger@yandex.ru
f8321665007831d70da10dd73f93baa39e98a55f
6a41d3e5e68a2eb6c01f70ceeb63339be1f0dd83
/CW/cw/table.cpp
0fcde218ab91a5cf461b98ca9824fb6ff6d93f9d
[ "MIT" ]
permissive
GandhiKK/CG-2021
dfb8fe596002033a7f59c550b3f805e4a7928024
4a5b217de323d482c00c44f0596ad455d219818c
refs/heads/master
2023-05-03T04:37:14.849275
2021-05-26T13:28:24
2021-05-26T13:28:24
347,633,067
0
1
null
2021-04-18T23:23:35
2021-03-14T12:39:06
C++
UTF-8
C++
false
false
1,927
cpp
#include "table.h" Table::Table(float width, float length, float height) { this->width = width; this->length = length; this->height = height; // chair float legWidth = width * 0.04f, legHeight = height * 0.495f; float sittingHeight = height * 0.05f; ironLegs.append(new Iron...
[ "gandhoogle@gmail.com" ]
gandhoogle@gmail.com
4816ef2919a40a99b4e8e80072c58b70f995a8d1
1ed5c8439f96af1b6c23b2abf2af8ee5af9f242a
/jni/_/Sender.cpp
453863c5c6a92b037490c7cc5adc0fb219715bb6
[ "Apache-2.0" ]
permissive
mhbai/Nanidroid
e7f25ae0daa854975d6b0f3f3d0b5ddf2d64a04e
c22e1531cc1cd9424314d57e7bc34ccb91d84cc5
refs/heads/master
2021-05-02T15:15:48.650973
2014-11-26T07:38:46
2014-11-26T07:38:46
null
0
0
null
null
null
null
SHIFT_JIS
C++
false
false
2,529
cpp
#include "Sender.h" #ifdef POSIX # include "Utilities.h" # include <stdio.h> # include <stdarg.h> #else # include "Utilities.h" //# include <mbctype.h> // for _ismbblead() #endif // グローバルオブジェクト Sender::sender_stream sender; // staticメンバ bool Sender::sm_sender_flag = true; int Sender::nest_ob...
[ "yenchilin@cattail-sw.com" ]
yenchilin@cattail-sw.com
90bff1473b9d212ec25dbdcdf0f9576bcd47cf4d
3ea221d81b109c00ad497673e0ba9de19872717c
/src/mapport.cpp
a92856a94095d23a09550c4ea754cdcbde468176
[ "MIT" ]
permissive
SpiffCoin/SpiffCoinCore
c8c35545f69026c7f44598cb7bee46350eb60608
6ffda97cd86690f8b374c85e700977a377de4d1e
refs/heads/master
2023-03-04T16:30:52.982091
2021-02-17T09:23:41
2021-02-17T09:23:41
339,622,234
0
0
null
null
null
null
UTF-8
C++
false
false
11,065
cpp
// Copyright (c) 2011-2020 The Bitcoin Core developers // Distributed under the MIT software license, see the accompanying // file COPYING or http://www.opensource.org/licenses/mit-license.php. #if defined(HAVE_CONFIG_H) #include <config/spiffcoin-config.h> #endif #include <mapport.h> #include <clientversion.h> #inc...
[ "trandin@tuta.io" ]
trandin@tuta.io
18ff5fb873ae796d80b95191dce97a7c2a0d77d6
af0ecafb5428bd556d49575da2a72f6f80d3d14b
/CodeJamCrawler/dataset/09_21291_99.cpp
6d46e852a520231369b29772d7124719797280a2
[]
no_license
gbrlas/AVSP
0a2a08be5661c1b4a2238e875b6cdc88b4ee0997
e259090bf282694676b2568023745f9ffb6d73fd
refs/heads/master
2021-06-16T22:25:41.585830
2017-06-09T06:32:01
2017-06-09T06:32:01
null
0
0
null
null
null
null
UTF-8
C++
false
false
2,123
cpp
//#include<stdafx.h> #include <stdlib.h> #include<cstring> #include<iostream> using namespace std; typedef struct node { int x; int y; }node; char map[110][110]; int xmap[110][110]; bool vist[110][110]; int N,M; char nowchar; node xmin(int x,int y,int N,int W,int E,int S) { node p; i...
[ "nikola.mrzljak@fer.hr" ]
nikola.mrzljak@fer.hr
8c7c176e35448b321284af00ae4b4ebce0f8d3e1
0638ec6ac920beead9b6f80d140327b75c87d226
/Homework/Seminar2/IMAX/GroupTicket.h
5f0e9713da8b1b2c395afb4ce775f354a8985952
[ "MIT" ]
permissive
5ko99/FMI-Semester-2
a92df30f37c2e1a42b376c5befbe0367e7ab895f
a7e7f2cc1ae7b3198728197c8b70d14156eb0996
refs/heads/master
2020-05-06T12:25:49.234080
2019-06-07T12:29:49
2019-06-07T12:29:49
180,122,330
0
0
null
null
null
null
UTF-8
C++
false
false
588
h
// // Created by petko on 31/05/19. // #ifndef IMAX_GROUPTICKET_H #define IMAX_GROUPTICKET_H #include "Ticket.h" #include<iostream> using namespace std; class GroupTicket: public Ticket { int* row; int* col; int len; void copyGroupTicket(const int*,const int*, int); void deleteGroupTicket(); publi...
[ "petko.krasimirov99@gmail.com" ]
petko.krasimirov99@gmail.com
4bbd95338ac8c9da7c6f674d290fe5b4ea72c25a
da03cdc56f318ee70fb96aa9164419f180d65d87
/my3dface.h
8e8c242ae4a355c2ca91a82b0818a6d61fc267fb
[]
no_license
alexanderguzhva/DFLighting
8cd1bcd09f74db4deaf7252c74e2d787b37e7f25
f9513bd564ed548d2f77cb8911550d9167601b5d
refs/heads/master
2020-05-07T16:06:45.720742
2015-02-28T22:33:50
2015-02-28T22:33:50
31,345,262
0
0
null
null
null
null
UTF-8
C++
false
false
368
h
#ifndef MY3DFACE_H #define MY3DFACE_H #include "facedirenum.h" #include "direction.h" namespace dflighting { // class My3DFace { public: int X; int Y; int Z; Direction Face; FaceDirEnum Dir; long SourceHits; long DestinationHits; // My3DFace(); My3DFace(int x, int y, int ...
[ "alexanderguzhva@gmail.com" ]
alexanderguzhva@gmail.com
0373677f09f4314a55ea8217ad75cb0f72ea8044
da3dde37cfab6ac43640f13b08e6de9e90070f9c
/include/gdkmm-3.0/gdkmm/private/dragcontext_p.h
64bd97267bce750ba4eb1dbabdb284699ad7ef52
[]
no_license
codenotes/gtk2-gtk3-sdk-2.24.30-3.20.2-2016-04-09-ts-win64
27ca673a945c76bd9ace095c510e703b52ddc9f7
952b68aebdf1c41e856db8a2f7efd120485ae9eb
refs/heads/master
2020-12-25T14:58:10.876852
2016-09-08T18:19:25
2016-09-08T18:19:25
67,728,820
1
0
null
null
null
null
UTF-8
C++
false
false
1,079
h
// Generated by gmmproc 2.48.0 -- DO NOT MODIFY! #ifndef _GDKMM_DRAGCONTEXT_P_H #define _GDKMM_DRAGCONTEXT_P_H #include <glibmm/private/object_p.h> #include <glibmm/class.h> namespace Gdk { class DragContext_Class : public Glib::Class { public: #ifndef DOXYGEN_SHOULD_SKIP_THIS typedef DragContext CppObjectType; ...
[ "gbrill@infusion.com" ]
gbrill@infusion.com
83a34dbac4af67b38e28a22bc65062c6eb6be157
8b4525741a33753a982788fdee97dc3d6c9d2789
/src/walletdb.h
9052581b88708b9ceec7c28b6a9b10239c213d44
[ "MIT" ]
permissive
ygtars/revu
b6fb59628cd9bf67aac86786b4cfee865feb3e4b
b824a844b8b8f508a00b05e09915b44ece32a844
refs/heads/master
2020-04-22T18:25:48.229140
2019-02-15T17:58:01
2019-02-15T17:58:01
170,576,715
0
0
null
null
null
null
UTF-8
C++
false
false
6,092
h
// Copyright (c) 2009-2010 Satoshi Nakamoto // Copyright (c) 2009-2013 The Bitcoin developers // Copyright (c) 2016-2017 The PIVX developers // Copyright (c) 2017 The Revu developers // Distributed under the MIT/X11 software license, see the accompanying // file COPYING or http://www.opensource.org/licenses/mit-license...
[ "arslanyigit357@gmail.com" ]
arslanyigit357@gmail.com
c6c0bad879a6e612af25d16aa8b5a3755c19f0a9
2dba8292ec7e64d06517eaf3550f4358a61d4d7d
/SRC/PerformanceTester.h
70a5f6fabfd9ba1fd77a7968be57d7e24ddd1781
[ "MIT" ]
permissive
srcbase/GenericCPPLib
855d89827060f425886c576bac688cc790bbee9f
69f66ca5331b3d9cf4d2fcd0b49f507984b6f454
refs/heads/master
2020-03-28T05:15:32.431072
2016-08-19T14:36:04
2016-08-19T14:36:04
null
0
0
null
null
null
null
UTF-8
C++
false
false
2,741
h
#ifndef PerformanceTesterH #define PerformanceTesterH //// [!] Version 1.002 [!] #include <ctime> #include <cassert> #include <chrono> #include <iostream> class PerformanceTester { public: struct TestResults { typedef decltype(std::chrono::steady_clock::now()) TTimePoint; typedef decltype((TTimePoint...
[ "dev3@exo-group.com" ]
dev3@exo-group.com
038ee102290cafc4620ae629a345741eeb5ec84c
21f01f0ea7092df49d5f711ab627dc5628e09d49
/Direct3D_17/Direct3D_17.v12.v12/cXMesh_Skinned.h
d82c37e1d1048e41b640664332c601551e649d7b
[]
no_license
JangMiKyung/DX2_pf_ver_2
9a44384b8334e7a15dc2daa4b757b728ea44a7f2
f3a919ae2c55a4fbfc1c5805d1070b575d164150
refs/heads/master
2020-06-14T03:32:52.045025
2016-12-04T02:18:30
2016-12-04T02:18:30
75,512,650
1
0
null
null
null
null
UHC
C++
false
false
3,548
h
#pragma once #include "cxmesh.h" #include "BoneHierachy.h" //본하이어 라키 #include "cSkinnedAnimation.h" class cTransform; class cCamera; class cXMesh_Skinned : public cXMesh { private: friend class BONE_HIERARCHY; //본하이어 라키는 내친구.... friend class cSkinnedAnimation; //cSkinnedAnimation 는 내친구... typedef st...
[ "mjismy@naver.com" ]
mjismy@naver.com
de3a06b900b700e19737dc31e90de0280d6d0ded
edf095aac56dd4f721634935cd42afd5f8df4025
/whole_new/Pi/Single_Sketch_Naive_Merged_Batch/generator_old.h
22ad4e424096c57fbbc0828e5ea98f187a8eb23b
[]
no_license
FatihTasyaran/SketchJournal
96559f215d166a696b704b9eaff43693c65c1096
770790ba68ea5b6fa1a00bc5130aa7ea74bd8cad
refs/heads/master
2022-10-30T20:20:28.263019
2020-06-08T14:09:57
2020-06-08T14:09:57
270,691,505
1
0
null
null
null
null
UTF-8
C++
false
false
4,599
h
#ifndef H_GENERATOR #define H_GENERATOR #include <iostream> #include <omp.h> #include <random> #include <algorithm> #include "common.h" using namespace std; void generateData(dtype* &data, unsigned long long no_stream, unsigned long long no_unique,int distNum) { data = new dtype[no_stream]; double max_rand = ...
[ "fatihtasyaran@sabanciuniv.edu" ]
fatihtasyaran@sabanciuniv.edu
171e3d4efc2b1f1160f1bfb0641f597d719ba13b
b9a526611569c4b2de2f9074eb2094608ead4519
/vecmul_cuda/amd_vecmul/vecmul_hip.cpp
fa15325ea884e88a1e326788644e0fe7b1aa7e89
[]
no_license
monil01/memory_research_ornl
03f0f57641841af1c7d4e9b2380c8f7874bcf880
09d51dd789de1d2387bbe13e85b53403c73c3cda
refs/heads/master
2023-08-07T13:19:23.792150
2021-10-07T07:58:30
2021-10-07T07:58:30
273,037,483
0
0
null
null
null
null
UTF-8
C++
false
false
2,442
cpp
#include "hip/hip_runtime.h" #include <stdio.h> #include <stdlib.h> #include <math.h> // CUDA kernel. Each thread takes care of one element of c __global__ void vecMul(float *a, float *b, float *c, int n, int stride) { // Get our global thread ID int id = blockIdx.x*blockDim.x+threadIdx.x; // Make sure w...
[ "monil01@gmail.com" ]
monil01@gmail.com
730b68f2f93ab8bf9835b16f902ac8d0a7201d8b
a7169b02d3f7a3841dd4e11d1ddf37a43c497bec
/198.house-robber.cpp
2e82ce073aecb3251878b88735d90f2063a88521
[]
no_license
devanshhalwai/Leetcode
02e3299677e2bf4aff9b20bb6d29d86bd25b2d61
1fd05b022f383991b2f7e44bc3555b8386b35506
refs/heads/master
2021-07-20T14:37:31.471075
2021-05-19T12:54:16
2021-05-19T12:54:16
249,648,220
0
0
null
null
null
null
UTF-8
C++
false
false
742
cpp
/* * @lc app=leetcode id=198 lang=cpp * * [198] House Robber */ // @lc code=start class Solution { public: int rob(vector<int>& hval) { int n=hval.size(); if (n == 0) return 0; int value1 = hval[0]; if (n == 1) return value1; int value2...
[ "devansh.halwai@gmail.com" ]
devansh.halwai@gmail.com
3a692dc3500250951c430fb7e6dc318fa4f36a8b
877fff5bb313ccd23d1d01bf23b1e1f2b13bb85a
/app/src/main/cpp/dir521/dir522/dir572/dir2774/dir2803/file2922.cpp
af34ed484caea09d39ff138b1154f7424de9d8a4
[]
no_license
tgeng/HugeProject
829c3bdfb7cbaf57727c41263212d4a67e3eb93d
4488d3b765e8827636ce5e878baacdf388710ef2
refs/heads/master
2022-08-21T16:58:54.161627
2020-05-28T01:54:03
2020-05-28T01:54:03
267,468,475
0
0
null
null
null
null
UTF-8
C++
false
false
111
cpp
#ifndef file2922 #error "macro file2922 must be defined" #endif static const char* file2922String = "file2922";
[ "tgeng@google.com" ]
tgeng@google.com
ffea1928386aa6bc059c194355531a2ae6c37ee3
edfee793c46bcd9d24c9d8ee5b603ffc67d39512
/source/libs/tensorflow/lite/kernels/kernel_util.cc
3eb3cec248e95ccfb651d2ede9351064a33a2306
[]
no_license
dimtass/tflite-micro-python-comparison
4aca03827ab6bbc531961b788f1b23a8e9a6630f
c8450a1406e9a28d55db3816387bb47b8c97ec41
refs/heads/master
2021-07-21T15:54:14.619448
2019-08-04T19:09:57
2019-08-04T19:09:57
221,082,997
1
1
null
2020-10-13T17:23:15
2019-11-11T22:39:20
C++
UTF-8
C++
false
false
10,248
cc
/* Copyright 2017 The TensorFlow Authors. All Rights Reserved. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or a...
[ "dimtass@gmail.com" ]
dimtass@gmail.com
2cf8ff35788d19508808153570c3f3bc8278a80a
d0de7ac1934028e8402f53d353dbe8a056b820d4
/globject.hpp
ce88245ac18fda8d8f45885a3cea6bfe4c3d3137
[ "Apache-2.0" ]
permissive
EfAlex/Puzzle-Box-Solver
4956ff3f7b527a5002a134cebe486966895e93d6
03316f936f567d98916f94d4571e01fb24b93617
refs/heads/master
2021-01-25T03:48:49.678432
2019-08-04T18:10:30
2019-08-04T18:10:30
3,859,187
0
0
null
null
null
null
UTF-8
C++
false
false
982
hpp
/* Copyright 2012 efalex <email> Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, s...
[ "efalex@gmail.com" ]
efalex@gmail.com